@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2003 Stuart Parmenter and others,
+ * Copyright (C) 1997-2009 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,12 +32,15 @@
  * organizationalPerson type. We are lenient.
  *
  */
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
 
 #if ENABLE_LDAP
 
+#include "address-book-ldap.h"
+
 #include <glib.h>
-#include <gnome.h>
 #include <sys/time.h>
 #include <string.h>
 #include <lber.h>
@@ -49,7 +52,6 @@
 #endif
 
 #include "address-book.h"
-#include "address-book-ldap.h"
 #include "information.h"
 #include "libbalsa-conf.h"
 #include <glib/gi18n.h>
@@ -112,8 +114,7 @@ static void libbalsa_address_book_ldap_load_config(LibBalsaAddressBook *ab,
 						   const gchar * prefix);
 
 static GList *libbalsa_address_book_ldap_alias_complete(LibBalsaAddressBook * ab,
-							 const gchar * prefix, 
-							 gchar ** new_prefix);
+							 const gchar * prefix);
 
 static LibBalsaAddress*
 libbalsa_address_book_ldap_get_address(LibBalsaAddressBook * ab,
@@ -547,7 +548,7 @@ lbabl_get_internet_address(LDAP *dir, LDAPMessage * e)
 
     if(!cn)
         cn = create_name(first, sn);
-    ia = internet_address_new_name(cn, email);
+    ia = internet_address_mailbox_new(cn, email);
     g_free(email); g_free(sn); g_free(cn); g_free(first);
 
     return ia;
@@ -910,7 +911,7 @@ rfc_2254_escape(const gchar *raw)
     gchar *str;
     gchar *step;
 
-    new = (gchar *)malloc((strlen(raw) * 3) + 1);
+    new = g_new(gchar, (strlen(raw) * 3) + 1);
     str = new;
     for (step = (gchar *)raw;
          step[0] != '\0';
@@ -942,15 +943,14 @@ rfc_2254_escape(const gchar *raw)
     }
     str[0] = '\0';
     str = g_strdup(new);
-    free(new);
+    g_free(new);
     return str;
 }
 
 
 static GList *
 libbalsa_address_book_ldap_alias_complete(LibBalsaAddressBook * ab,
-					  const gchar * prefix, 
-					  gchar ** new_prefix)
+					  const gchar * prefix)
 {
     static struct timeval timeout = { 15, 0 }; /* 15 sec timeout */
     LibBalsaAddressBookLdap *ldap_ab;
@@ -976,7 +976,6 @@ libbalsa_address_book_ldap_alias_complete(LibBalsaAddressBook * ab,
      * Attempt to search for e-mail addresses.  It returns success
      * or failure, but not all the matches.
      */
-    if(new_prefix) *new_prefix = NULL;
     ldap = rfc_2254_escape(prefix);
 
     filter = g_strdup_printf("(&(objectClass=organizationalPerson)(mail=*)"
@@ -999,8 +998,6 @@ libbalsa_address_book_ldap_alias_complete(LibBalsaAddressBook * ab,
 	    for(e = ldap_first_entry(ldap_ab->directory, result);
 		e != NULL; e = ldap_next_entry(ldap_ab->directory, e)) {
 		addr = lbabl_get_internet_address(ldap_ab->directory, e);
-		if(new_prefix && !*new_prefix) 
-		    *new_prefix = internet_address_to_string(addr, FALSE);
 		res = g_list_prepend(res, addr);
 	    }
     case LDAP_SIZELIMIT_EXCEEDED:
