@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2005 Stuart Parmenter and others,
+ * Copyright (C) 1997-2009 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,16 +27,19 @@
  * books ...
  */
 
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
+#include "address-book-text.h"
 
 #include <sys/stat.h>
 #include <string.h>
+#include <unistd.h>
 
-#include "address-book-text.h"
 #include "abook-completion.h"
 #include "libbalsa-conf.h"
 #include "misc.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 
 /* FIXME: Perhaps the whole thing could be rewritten to use a g_scanner ?? */
 
@@ -77,8 +80,7 @@ libbalsa_address_book_text_load_config(LibBalsaAddressBook * ab,
                                        const gchar * prefix);
 static GList *
 libbalsa_address_book_text_alias_complete(LibBalsaAddressBook * ab,
-                                          const gchar * prefix,
-                                          gchar ** new_prefix);
+                                          const gchar * prefix);
 
 /* GObject class stuff */
 
@@ -147,8 +149,9 @@ libbalsa_address_book_text_init(LibBalsaAddressBookText * ab_text)
     ab_text->mtime = 0;
 
     ab_text->name_complete =
-        g_completion_new((GCompletionFunc) completion_data_extract);
-    g_completion_set_compare(ab_text->name_complete, strncmp_word);
+        libbalsa_completion_new((LibBalsaCompletionFunc)
+                                completion_data_extract);
+    libbalsa_completion_set_compare(ab_text->name_complete, strncmp_word);
 }
 
 typedef struct {
@@ -189,7 +192,7 @@ libbalsa_address_book_text_finalize(GObject * object)
 
     g_list_foreach(ab_text->name_complete->items,
                    (GFunc) completion_data_free, NULL);
-    g_completion_free(ab_text->name_complete);
+    libbalsa_completion_free(ab_text->name_complete);
 
     G_OBJECT_CLASS(parent_class)->finalize(object);
 }
@@ -246,7 +249,7 @@ lbab_text_group_address(const gchar * group_name,
     if (!lbab_text_group_addresses || !lbab_text_group_addresses->next)
         return;
 
-    ia = internet_address_new_group(group_name);
+    ia = internet_address_group_new(group_name);
     for (l = lbab_text_group_addresses; l; l = l->next) {
         GList *mailbox;
         LibBalsaAddress *address = LIBBALSA_ADDRESS(l->data);
@@ -254,16 +257,16 @@ lbab_text_group_address(const gchar * group_name,
         for (mailbox = address->address_list; mailbox;
              mailbox = mailbox->next) {
             InternetAddress *member =
-                internet_address_new_name(address->full_name,
-                                          mailbox->data);
-            internet_address_add_member(ia, member);
-            internet_address_unref(member);
+                internet_address_mailbox_new(address->full_name,
+					     mailbox->data);
+            internet_address_group_add_member(ia, member);
+            g_object_unref(member);
         }
     }
     g_slist_free(lbab_text_group_addresses);
 
     cmp_data = completion_data_new(ia, NULL);
-    internet_address_unref(ia);
+    g_object_unref(ia);
     *completion_list = g_list_prepend(*completion_list, cmp_data);
 }
 #endif                          /* MAKE_GROUP_BY_ORGANIZATION */
@@ -309,7 +312,7 @@ lbab_text_load_file(LibBalsaAddressBookText * ab_text, FILE * stream)
 
     g_list_foreach(ab_text->name_complete->items,
                    (GFunc) completion_data_free, NULL);
-    g_completion_clear_items(ab_text->name_complete);
+    libbalsa_completion_clear_items(ab_text->name_complete);
 
     parse_address =
         LIBBALSA_ADDRESS_BOOK_TEXT_GET_CLASS(ab_text)->parse_address;
@@ -352,28 +355,28 @@ lbab_text_load_file(LibBalsaAddressBookText * ab_text, FILE * stream)
             && LIBBALSA_ADDRESS_BOOK(ab_text)->dist_list_mode) {
             /* Create a group address. */
             InternetAddress *ia =
-                internet_address_new_group(address->full_name);
+                internet_address_group_new(address->full_name);
 
             for (l = address->address_list; l; l = l->next) {
                 InternetAddress *member =
-                    internet_address_new_name(NULL, l->data);
-                internet_address_add_member(ia, member);
-                internet_address_unref(member);
+                    internet_address_mailbox_new(NULL, l->data);
+                internet_address_group_add_member((InternetAddressGroup *)ia, member);
+                g_object_unref(member);
             }
             cmp_data = completion_data_new(ia, address->nick_name);
             completion_list = g_list_prepend(completion_list, cmp_data);
-            internet_address_unref(ia);
+            g_object_unref(ia);
         } else {
             /* Create name addresses. */
             GList *l;
 
             for (l = address->address_list; l; l = l->next) {
                 InternetAddress *ia =
-                    internet_address_new_name(address->full_name, l->data);
+                    internet_address_mailbox_new(address->full_name, l->data);
                 cmp_data = completion_data_new(ia, address->nick_name);
                 completion_list =
                     g_list_prepend(completion_list, cmp_data);
-                internet_address_unref(ia);
+                g_object_unref(ia);
             }
         }
 
@@ -406,7 +409,7 @@ lbab_text_load_file(LibBalsaAddressBookText * ab_text, FILE * stream)
 #endif                          /* MAKE_GROUP_BY_ORGANIZATION */
 
     completion_list = g_list_reverse(completion_list);
-    g_completion_add_items(ab_text->name_complete, completion_list);
+    libbalsa_completion_add_items(ab_text->name_complete, completion_list);
     g_list_free(completion_list);
 
     return TRUE;
@@ -699,8 +702,7 @@ libbalsa_address_book_text_load_config(LibBalsaAddressBook * ab,
 /* Alias complete method */
 static GList *
 libbalsa_address_book_text_alias_complete(LibBalsaAddressBook * ab,
-                                          const gchar * prefix,
-                                          char **new_prefix)
+                                          const gchar * prefix)
 {
     LibBalsaAddressBookText *ab_text = LIBBALSA_ADDRESS_BOOK_TEXT(ab);
     FILE *stream;
@@ -725,10 +727,11 @@ libbalsa_address_book_text_alias_complete(LibBalsaAddressBook * ab,
     fclose(stream);
 
     for (list =
-         g_completion_complete(ab_text->name_complete, (gchar *) prefix,
-                               new_prefix); list; list = list->next) {
+         libbalsa_completion_complete(ab_text->name_complete,
+                                      (gchar *) prefix);
+         list; list = list->next) {
         InternetAddress *ia = ((CompletionData *) list->data)->ia;
-        internet_address_ref(ia);
+        g_object_ref(ia);
         res = g_list_prepend(res, ia);
     }
 
