@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2005 Stuart Parmenter and others,
+ * Copyright (C) 1997-2009 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,11 +28,13 @@
  * Obviously, the best method would be to have file encoded in UTF-8.
  */
 
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
+#include "address-book-vcard.h"
 
 #include <string.h>
-#include "address-book-vcard.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 
 /* FIXME: Perhaps the whole thing could be rewritten to use a g_scanner ?? */
 
@@ -329,8 +331,8 @@ libbalsa_address_book_vcard_parse_address(FILE * stream,
 	/*
 	 * fetch all e-mail fields
 	 */
-	if (g_ascii_strncasecmp(string, "EMAIL;", 6) == 0) {
-	    gchar *ptr = strchr(string+6, ':');
+	if (g_ascii_strncasecmp(string, "EMAIL", 5) == 0) {
+	    gchar *ptr = strchr(string + 5, ':');
 	    if (ptr) {
 		address_list =
 		    g_list_prepend(address_list, g_strdup(ptr + 1));
