@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2000 Stuart Parmenter and others,
+ * Copyright (C) 1997-2009 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,13 +23,18 @@
 #ifndef __LIBBALSA_BODY_H__
 #define __LIBBALSA_BODY_H__
 
+#ifndef BALSA_VERSION
+# error "Include config.h before this file."
+#endif
+
 #include <stdio.h>
+#include <sys/stat.h>
 
 #include <glib.h>
 #include <gmime/gmime.h>
 #include <gdk/gdk.h>
 
-#include "config.h"
+#include "libbalsa-vfs.h"
 
 #ifdef HAVE_GPGME
 #include "gmime-gpgme-signature.h"
@@ -64,6 +69,7 @@ struct _LibBalsaMessageBody {
     LibBalsaMessage *message;	/* The message of which this is a part */
     /* FIXME: remove buffer and buf_len to decrease memory usage. */
     gchar *buffer;		/* holds raw data of the MIME part, or NULL */
+    gchar *html_buffer;         /* holds the html representation of the part or NULL */
     ssize_t buflen;             /* size of the block */
     LibBalsaMessageHeaders *embhdrs;  /* headers of a message/rfc822 part */
     LibBalsaMessageBodyType body_type;
@@ -73,6 +79,7 @@ struct _LibBalsaMessageBody {
     const gchar *content_dsp;	/* content-disposition */ 
     const gchar *content_id;    /* content-id */
     gchar *filename;		/* holds filename for attachments and such (used mostly for sending) */
+    LibbalsaVfs * file_uri;     /* file uri for attachments (used for sending) */
     LibBalsaAttachMode attach_mode; /* attachment mode for sending */
     gchar *temp_filename;	/* Holds the filename of a the temporary file where this part is saved */
     gchar *charset;		/* the charset, used for sending, replying. */
@@ -103,11 +110,18 @@ gssize libbalsa_message_body_get_content(LibBalsaMessageBody * body,
 GdkPixbuf *libbalsa_message_body_get_pixbuf(LibBalsaMessageBody * body,
                                             GError ** err);
 
-gboolean libbalsa_message_body_save_fd(LibBalsaMessageBody * body, int fd,
-                                       gboolean filter_crlf, GError **err);
+gboolean libbalsa_message_body_save_stream(LibBalsaMessageBody * body,
+                                           GMimeStream * dest,
+                                           gboolean filter_crlf,
+                                           GError **err);
 gboolean libbalsa_message_body_save(LibBalsaMessageBody * body,
                                     const gchar * filename, mode_t mode,
                                     gboolean filter_crlf, GError **err);
+gboolean libbalsa_message_body_save_vfs(LibBalsaMessageBody * body,
+                                        LibbalsaVfs * dest,
+                                        mode_t mode,
+                                        gboolean filter_crlf,
+                                        GError **err);
 gboolean libbalsa_message_body_save_temporary(LibBalsaMessageBody * body,
                                               GError **err);
 
