@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2002 Stuart Parmenter and others,
+ * Copyright (C) 1997-2009 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,6 +22,9 @@
 #ifndef __FOLDER_SCANNERS_H__
 #define __FOLDER_SCANNERS_H__
 
+#include <glib-object.h>
+#include "libbalsa.h"
+
 typedef gboolean LocalCheck(const gchar * fn, guint depth);
 typedef gboolean LocalMark(gpointer node);
 typedef gpointer LocalHandler(gpointer root, const char *d_name,
