@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /*
  * gmime/gpgme glue layer library
- * Copyright (C) 2004 Albrecht Dre <albrecht.dress@arcor.de>
+ * Copyright (C) 2004-2011 Albrecht Dreß <albrecht.dress@arcor.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,10 +23,11 @@
 # include "config.h"
 #endif                          /* HAVE_CONFIG_H */
 
+#include <ctype.h>
 #include <gpgme.h>
 #include <string.h>
 #include <glib.h>
-#include "gmime-gpgme-context.h"
+#include "libbalsa-gpgme.h"
 #include "gmime-gpgme-signature.h"
 
 
@@ -37,7 +38,6 @@ static void g_mime_gpgme_sigstat_class_init(GMimeGpgmeSigstatClass *
 					    klass);
 static void g_mime_gpgme_sigstat_finalize(GMimeGpgmeSigstat * self);
 static void g_mime_gpgme_sigstat_init(GMimeGpgmeSigstat * self);
-static gchar *fix_EMail_info(gchar * str);
 
 
 /* GMimeGpgmeSigstat related stuff */
@@ -83,9 +83,6 @@ g_mime_gpgme_sigstat_new_from_gpgme_ctx(gpgme_ctx_t ctx)
 {
     GMimeGpgmeSigstat *sig_stat;
     gpgme_verify_result_t result;
-    gpgme_key_t key;
-    gpgme_subkey_t subkey;
-    gpgme_user_id_t uid;
     gpgme_error_t err;
 
     g_return_val_if_fail(ctx, NULL);
@@ -104,53 +101,14 @@ g_mime_gpgme_sigstat_new_from_gpgme_ctx(gpgme_ctx_t ctx)
     sig_stat->fingerprint = g_strdup(result->signatures->fpr);
     sig_stat->sign_time = result->signatures->timestamp;
     sig_stat->status = gpgme_err_code(result->signatures->status);
+    sig_stat->validity = result->signatures->validity;
 
     /* try to get the related key */
-    err = gpgme_get_key(ctx, sig_stat->fingerprint, &key, 0);
-    if (err != GPG_ERR_NO_ERROR) {
+    err = gpgme_get_key(ctx, sig_stat->fingerprint, &sig_stat->key, 0);
+    if (err != GPG_ERR_NO_ERROR)
           g_message("could not retrieve the key with fingerprint %s: %s: %s",
                     sig_stat->fingerprint, gpgme_strsource(err),
                     gpgme_strerror(err));
-	return sig_stat;
-    }
-    if (key == NULL)
-	return sig_stat;
-
-    /* the key is available */
-    sig_stat->protocol = key->protocol;
-    sig_stat->issuer_serial = g_strdup(key->issuer_serial);
-    sig_stat->issuer_name = g_strdup(key->issuer_name);
-    sig_stat->chain_id = g_strdup(key->chain_id);
-    sig_stat->trust = key->owner_trust;
-    uid = key->uids;
-
-    /* Note: there is no way to determine which user id has been used to
-     * create the signature. We therefore pick the validity of the primary
-     * one and scan uid's to get useable name, email and uid strings */
-    sig_stat->validity = uid->validity;
-    while (uid) {
-	if (!sig_stat->sign_name && uid->name && *uid->name)
-	    sig_stat->sign_name = g_strdup(uid->name);
-	if (!sig_stat->sign_email && uid->email && *uid->email)
-	    sig_stat->sign_email = g_strdup(uid->email);
-	if (!sig_stat->sign_uid && uid->uid && *uid->uid)
-	    sig_stat->sign_uid = fix_EMail_info(g_strdup(uid->uid));
-	uid = uid->next;
-    }
-
-    /* get the subkey which can sign */
-    subkey = key->subkeys;
-    while (subkey && !subkey->can_sign)
-	subkey = subkey->next;
-    if (subkey) {
-	sig_stat->key_created = subkey->timestamp;
-	sig_stat->key_expires = subkey->expires;
-	sig_stat->key_revoked = subkey->revoked;
-	sig_stat->key_expired = subkey->expired;
-	sig_stat->key_disabled = subkey->disabled;
-	sig_stat->key_invalid = subkey->invalid;
-    }
-    gpgme_key_unref(key);
 
     return sig_stat;
 }
@@ -166,84 +124,107 @@ g_mime_gpgme_sigstat_class_init(GMimeGpgmeSigstatClass * klass)
 	(GObjectFinalizeFunc) g_mime_gpgme_sigstat_finalize;
 }
 
-
 static void
 g_mime_gpgme_sigstat_finalize(GMimeGpgmeSigstat * self)
 {
-    g_free(self->sign_name);
-    self->sign_name = NULL;
-    g_free(self->sign_email);
-    self->sign_email = NULL;
     g_free(self->fingerprint);
     self->fingerprint = NULL;
-    g_free(self->sign_uid);
-    self->sign_uid = NULL;
-    g_free(self->issuer_serial);
-    self->issuer_serial = NULL;
-    g_free(self->issuer_name);
-    self->issuer_name = NULL;
-    g_free(self->chain_id);
-    self->chain_id = NULL;
+    if (self->key)
+	gpgme_key_unref(self->key);
+    self->key = NULL;
 
     g_mime_gpgme_sigstat_parent_class->finalize(G_OBJECT(self));
 }
 
+static gchar *
+hex_decode(const gchar *hexstr)
+{
+    gchar *result;
+    gchar *outp;
+    int inlen;
+
+    inlen = strlen(hexstr);
+    if ((inlen & 1) == 1)
+        return g_strdup(hexstr);
+
+    result = g_new0(gchar, (inlen >> 1) + 1);
+    for (outp = result; *hexstr; outp++) {
+        if (isdigit(*hexstr))
+            *outp = (*hexstr - '0') << 4;
+        else
+            *outp = (toupper(*hexstr) -'A' + 10) << 4;
+        hexstr++;
+        if (isdigit(*hexstr))
+            *outp |= *hexstr - '0';
+        else
+            *outp |= toupper(*hexstr) -'A' + 10;
+        hexstr++;
+    }
+    return result;
+}
+
+/*
+ * Change some fields in a S/MIME certificate to human-readable text.
+ * Note: doesn't do any sophisticated error-checking...
+ */
+gchar *
+libbalsa_cert_subject_readable(const gchar *subject)
+{
+    const struct {
+        gchar *ldap_id;
+        gchar *readable;
+    } ldap_id_list[] = {
+        { .ldap_id = "2.5.4.4", .readable = "sn" },
+        { .ldap_id = "2.5.4.5", .readable = "serialNumber" },
+        { .ldap_id = "2.5.4.42", .readable = "givenName" },
+        { .ldap_id = "1.2.840.113549.1.9.1", .readable = "email" },
+        { .ldap_id = NULL, .readable = NULL }
+    }, *ldap_elem;
+    gchar **elements;
+    gint n;
+    GString *result;
+
+    if (!subject)
+        return NULL;
+
+    result = g_string_new(NULL);
+    elements = g_strsplit(subject, ",", -1);
+    for (n = 0; elements[n]; n++) {
+        gchar *equals;
+
+        equals = strchr(elements[n], '=');
+        if (equals) {
+            *equals++ = '\0';
+            for (ldap_elem = ldap_id_list;
+                 ldap_elem->ldap_id && strcmp(ldap_elem->ldap_id, elements[n]);
+                 ldap_elem++);
+            if (ldap_elem->ldap_id)
+                result = g_string_append(result, ldap_elem->readable);
+            else
+                result = g_string_append(result, elements[n]);
+            result = g_string_append_c(result, '=');
+            
+            if (*equals == '#') {
+                gchar *decoded;
+
+                decoded = hex_decode(equals + 1);
+                result = g_string_append(result, decoded);
+                g_free(decoded);
+            } else
+                result = g_string_append(result, equals);
+        } else
+            result = g_string_append(result, elements[n]);
+        if (elements[n + 1])
+            result = g_string_append_c(result, ',');
+    }
+    g_strfreev(elements);
+    return g_string_free(result, FALSE);
+}
 
 static void
 g_mime_gpgme_sigstat_init(GMimeGpgmeSigstat * self)
 {
     self->status = GPG_ERR_NOT_SIGNED;
-    self->sign_name = NULL;
-    self->sign_email = NULL;
+    self->key = NULL;
     self->fingerprint = NULL;
-    self->sign_uid = NULL;
-    self->issuer_serial = NULL;
-    self->issuer_name = NULL;
-    self->chain_id = NULL;
-}
-
-
-/*
- * Change an EMail field in a S/MIME certificate to human-readable text.
- * Note: doesn't do any sophisticated error-checking...
- */
-static gchar *
-fix_EMail_info(gchar * str)
-{
-    gchar *p = strstr(str, "1.2.840.113549.1.9.1=#");
-    GString *result;
-
-    if (!p)
-	return str;
-
-    *p = '\0';
-    p += 22;
-    result = g_string_new(str);
-    result = g_string_append(result, "EMail=");
-    while (*p != '\0' && *p != ',') {
-	gchar x = 0;
-
-	if (*p >= 'A' && *p <= 'F')
-	    x = (*p - 'A' + 10) << 4;
-	else if (*p >= 'a' && *p <= 'f')
-	    x = (*p - 'a' + 10) << 4;
-	else if (*p >= '0' && *p <= '9')
-	    x = (*p - '0') << 4;
-	p++;
-	if (*p != '\0' && *p != ',') {
-	    if (*p >= 'A' && *p <= 'F')
-		x += *p - 'A' + 10;
-	    else if (*p >= 'a' && *p <= 'f')
-		x += *p - 'a' + 10;
-	    else if (*p >= '0' && *p <= '9')
-		x += *p - '0';
-	    p++;
-	}
-	result = g_string_append_c(result, x);
-    }
-    result = g_string_append(result, p);
-    g_free(str);
-    p = result->str;
-    g_string_free(result, FALSE);
-    return p;
 }
