@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /*
- * gmime/gpgme glue layer library
- * Copyright (C) 2004 Albrecht Dre <albrecht.dress@arcor.de>
+ * gmime/gpgme implementation for RFC2440 parts
+ * Copyright (C) 2004-2011 Albrecht Dreß <albrecht.dress@arcor.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,21 +20,35 @@
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif                          /* HAVE_CONFIG_H */
-#include "gmime-part-rfc2440.h"
 
 #include <string.h>
+#include <glib.h>
+#include <gtk/gtk.h>
 #include <gmime/gmime.h>
+#include "libbalsa-gpgme.h"
+#include "gmime-part-rfc2440.h"
 
 
 #define RFC2440_BUF_LEN    4096
 
+
+/** \brief Check for a part's RFC 2440 protection
+ *
+ * \param part GMime part which shall be inspected.
+ * \return The OpenPGP (RFC 2440) protection of the part.
+ *
+ * Check if the passed part is RFC 2440 signed or encrypted by looking for
+ * the "magic" strings defined there.  Note that parts which include extra
+ * data before the beginning or after the end of signed or encryped matter
+ * are always classified as GMIME_PART_RFC2440_NONE.
+ */
 GMimePartRfc2440Mode
 g_mime_part_check_rfc2440(GMimePart * part)
 {
-    GMimeDataWrapper * wrapper;
-    GMimeStream * stream;
+    GMimeDataWrapper *wrapper;
+    GMimeStream *stream;
     ssize_t slen;
     gchar buf[RFC2440_BUF_LEN];
     GMimePartRfc2440Mode retval = GMIME_PART_RFC2440_NONE;
@@ -58,7 +72,7 @@ g_mime_part_check_rfc2440(GMimePart * part)
 	    strstr(buf, "-----END PGP MESSAGE-----"))
 	    retval = GMIME_PART_RFC2440_ENCRYPTED;
 	else if (!strncmp(buf, "-----BEGIN PGP SIGNED MESSAGE-----", 34)) {
-	    gchar * p1, * p2;
+	    gchar *p1, *p2;
 
 	    p1 = strstr(buf, "-----BEGIN PGP SIGNATURE-----");
 	    p2 = strstr(buf, "-----END PGP SIGNATURE-----");
@@ -68,14 +82,15 @@ g_mime_part_check_rfc2440(GMimePart * part)
     } else {
 	/* check if the beginning of the stream matches */
 	g_mime_stream_read(stream, buf, 34);
-	g_mime_stream_seek(stream, 1 - RFC2440_BUF_LEN,  GMIME_STREAM_SEEK_END);
+	g_mime_stream_seek(stream, 1 - RFC2440_BUF_LEN,
+			   GMIME_STREAM_SEEK_END);
 	if (!strncmp(buf, "-----BEGIN PGP MESSAGE-----", 27)) {
 	    g_mime_stream_read(stream, buf, RFC2440_BUF_LEN - 1);
 	    buf[RFC2440_BUF_LEN - 1] = '\0';
 	    if (strstr(buf, "-----END PGP MESSAGE-----"))
 		retval = GMIME_PART_RFC2440_ENCRYPTED;
 	} else if (!strncmp(buf, "-----BEGIN PGP SIGNED MESSAGE-----", 34)) {
-	    gchar * p1, * p2;
+	    gchar *p1, *p2;
 
 	    g_mime_stream_read(stream, buf, RFC2440_BUF_LEN - 1);
 	    buf[RFC2440_BUF_LEN - 1] = '\0';
@@ -90,20 +105,30 @@ g_mime_part_check_rfc2440(GMimePart * part)
 }
 
 
-/*
- * RFC2440 sign, encrypt or sign and encrypt a gmime part using the
- * gmime gpgme context ctx. If sign_userid is not NULL, part will be
- * signed. If recipients is not NULL, encrypt part for recipients. If
- * both are not null, part will be first signed and then
+/** \brief RFC 2440 sign and/or encrypt a GMime part
+ *
+ * \param part GMime part which shall be signed and/or encrypted.
+ * \param sign_userid User ID of the signer, or NULL fo no signature.
+ * \param recipients Array of User ID for which the matter shall be
+ *        encrypted using their public keys, or NULL for no encryption.
+ * \param trust_all_keys TRUE if all low-truct keys shall be accepted for
+ *        encryption.
+ * \param parent Parent window to be passed to the callback functions.
+ * \param error Filled with error information on error.
+ * \return 0 on success, or -1 on error.
+ *
+ * RFC2440 sign, encrypt or sign and encrypt a gmime part.  If sign_userid
+ * is not NULL, part will be signed.  If recipients is not NULL, encrypt
+ * part for recipients.  If both are not null, part will be both signed and
  * encrypted. Returns 0 on success or -1 on fail. If any operation
  * failed, an exception will be set on err to provide more
  * information.
  */
 int
-g_mime_part_rfc2440_sign_encrypt(GMimePart * part,
-				 GMimeGpgmeContext * ctx,
+g_mime_part_rfc2440_sign_encrypt(GMimePart * part, const char *sign_userid,
 				 GPtrArray * recipients,
-				 const char *sign_userid, GError ** err)
+				 gboolean trust_all, GtkWindow * parent,
+				 GError ** err)
 {
     GMimeDataWrapper *wrapper;
     GMimeStream *stream, *cipherstream;
@@ -111,9 +136,6 @@ g_mime_part_rfc2440_sign_encrypt(GMimePart * part,
     gint result;
 
     g_return_val_if_fail(GMIME_IS_PART(part), -1);
-    g_return_val_if_fail(GMIME_IS_GPGME_CONTEXT(ctx), -1);
-    g_return_val_if_fail(GMIME_CIPHER_CONTEXT(ctx)->sign_protocol != NULL,
-			 -1);
     g_return_val_if_fail(recipients != NULL || sign_userid != NULL, -1);
 
     /* get the raw content */
@@ -128,30 +150,31 @@ g_mime_part_rfc2440_sign_encrypt(GMimePart * part,
     g_mime_stream_mem_set_owner(GMIME_STREAM_MEM(cipherstream), TRUE);
 
     /* do the crypto operation */
-    ctx->singlepart_mode = TRUE;
-    if (recipients == NULL)
-	result =
-	    g_mime_cipher_context_sign(GMIME_CIPHER_CONTEXT(ctx), sign_userid,
-			       GMIME_CIPHER_HASH_DEFAULT, stream,
-			       cipherstream, err);
+    if (recipients == NULL) {
+	if (libbalsa_gpgme_sign
+	    (sign_userid, stream, cipherstream, GPGME_PROTOCOL_OpenPGP,
+	     TRUE, parent, err) == GPGME_MD_NONE)
+	    result = -1;
     else
+	    result = 0;
+    } else
 	result =
-	    g_mime_cipher_context_encrypt(GMIME_CIPHER_CONTEXT(ctx),
-				  sign_userid != NULL, sign_userid,
-				  recipients, stream, cipherstream, err);
+	    libbalsa_gpgme_encrypt(recipients, sign_userid, stream,
+				   cipherstream, GPGME_PROTOCOL_OpenPGP,
+				   TRUE, trust_all, parent, err);
     if (result == -1) {
 	g_object_unref(cipherstream);
 	return -1;
     }
 
-    /* add the headers to encrypted ascii armor output: as there is no "insert"
-     * method for the byte array, first remove the leading "BEGIN PGP MESSAGE"
-     * (27 chars) and prepend it again... */
+    /* add the headers to encrypted ascii armor output: as there is no
+     * "insert" method for the byte array, first remove the leading "BEGIN
+     * PGP MESSAGE" (27 chars) and prepend it again... */
     if (recipients && g_mime_object_get_content_type(GMIME_OBJECT(part))) {
 	const gchar *charset =
 	    g_mime_object_get_content_type_parameter(GMIME_OBJECT(part),
 						     "charset");
-	gchar * rfc2440header;
+	gchar *rfc2440header;
 	
 	rfc2440header =
 	    g_strdup_printf("-----BEGIN PGP MESSAGE-----\nCharset: %s\n"
@@ -171,16 +194,19 @@ g_mime_part_rfc2440_sign_encrypt(GMimePart * part,
     /*
      * Paranoia: set the encoding of a signed part to quoted-printable (not
      * requested by RFC2440, but it's safer...). If we encrypted use 7-bit
-     * and set the charset to us-ascii instead, as gpg added it's own armor.
+     * and set the charset to us-ascii instead, as gpg added it's own
+     * armor.
      */
     if (recipients == NULL) {
-	if (g_mime_part_get_content_encoding(part) != GMIME_CONTENT_ENCODING_BASE64)
+	if (g_mime_part_get_content_encoding(part) !=
+	    GMIME_CONTENT_ENCODING_BASE64)
 	    g_mime_part_set_content_encoding(part,
 				     GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE);
 	g_mime_data_wrapper_set_encoding(wrapper,
 					 GMIME_CONTENT_ENCODING_DEFAULT);
     } else {
-	g_mime_part_set_content_encoding(part, GMIME_CONTENT_ENCODING_7BIT);
+	g_mime_part_set_content_encoding(part,
+					 GMIME_CONTENT_ENCODING_7BIT);
 	g_mime_data_wrapper_set_encoding(wrapper,
 					 GMIME_CONTENT_ENCODING_7BIT);
 	g_mime_object_set_content_type_parameter(GMIME_OBJECT(part),
@@ -195,25 +221,27 @@ g_mime_part_rfc2440_sign_encrypt(GMimePart * part,
 }
 
 
-/*
- * Verify the signature of the RFC 2440 signed part using the gpgme
- * context ctx and return the validity as determined by the crypto
- * routines or NULL on error. In the latter case, an exception will be
- * set on err to provide more information. Upon success, the content
- * of part is replaced by the verified output of the crypto engine.
+/* \brief Verify a RFC 2440 signed part
+ *
+ * \param part GMime part which shall be verified.
+ * \param error Filled with error information on error.
+ * \return A new signature status object on success, or NULL on error.
+ *
+ * Verify the signature of the RFC 2440 signed part and return the
+ * signature status as determined by the crypto routines or NULL on error.
+ * In the latter case, an exception will be set on err to provide more
+ * information.  Upon success, the content of part is replaced by the
+ * verified output of the crypto engine.
  */
-GMimeSignatureValidity *
-g_mime_part_rfc2440_verify(GMimePart * part,
-			   GMimeGpgmeContext * ctx, GError ** err)
+GMimeGpgmeSigstat *
+g_mime_part_rfc2440_verify(GMimePart * part, GError ** err)
 {
-    GMimeStream *stream, *plainstream;
-    GMimeDataWrapper * wrapper;
-    GMimeSignatureValidity *valid;
+    GMimeStream *stream;
+    GMimeStream *plainstream;
+    GMimeDataWrapper *wrapper;
+    GMimeGpgmeSigstat *result;
 
     g_return_val_if_fail(GMIME_IS_PART(part), NULL);
-    g_return_val_if_fail(GMIME_IS_GPGME_CONTEXT(ctx), NULL);
-    g_return_val_if_fail(GMIME_CIPHER_CONTEXT(ctx)->sign_protocol != NULL,
-			 NULL);
 
     /* get the raw content */
     wrapper = g_mime_part_get_content_object(GMIME_PART(part));
@@ -226,14 +254,12 @@ g_mime_part_rfc2440_verify(GMimePart * part,
     plainstream = g_mime_stream_mem_new();
 
     /* verify the signature */
-    ctx->singlepart_mode = TRUE;
-    valid =
-	g_mime_cipher_context_verify(GMIME_CIPHER_CONTEXT(ctx),
-			     GMIME_CIPHER_HASH_DEFAULT, stream,
-			     plainstream, err);
+    result =
+	libbalsa_gpgme_verify(stream, plainstream, GPGME_PROTOCOL_OpenPGP,
+			      TRUE, err);
 
     /* upon success, replace the signed content by the checked one */
-    if (valid) {
+    if (result && g_mime_stream_length(plainstream) > 0) {
 	GMimeDataWrapper *wrapper = g_mime_data_wrapper_new();
 
 	g_mime_data_wrapper_set_stream(wrapper, plainstream);
@@ -242,32 +268,36 @@ g_mime_part_rfc2440_verify(GMimePart * part,
     }
     g_object_unref(plainstream);
 
-    return valid;
+    return result;
 }
 
 
-/*
- * Decrypt the RFC 2440 encrypted part using the gmime gpgme context
- * ctx and return 0 on success or -1 for fail. In the latter case, an
- * exception will be set on err to provide more information. Upon
+/* \brief Decrypt a RFC 2440 encrypted part
+ *
+ * \param part GMime part which shall be verified.
+ * \param parent Parent window to be passed to the passphrase callback
+ *        function.
+ * \param error Filled with error information on error.
+ * \return A new signature status object on success, or NULL on error.
+ *
+ * Decrypt the RFC 2440 encrypted part and return the signature status as
+ * determined by the crypto routines or NULL on error.  In the latter case,
+ * an exception will be set on err to provide more information.  Upon
  * success, the content of part is replaced by the decrypted output of
  * the crypto engine. If the input was also signed, the signature is
- * verified and the result is placed in ctx by the underlying gpgme
- * context.
+ * verified.
  */
-GMimeSignatureValidity *
-g_mime_part_rfc2440_decrypt(GMimePart * part,
-			    GMimeGpgmeContext * ctx, GError ** err)
+GMimeGpgmeSigstat *
+g_mime_part_rfc2440_decrypt(GMimePart * part, GtkWindow * parent,
+			    GError ** err)
 {
-    GMimeStream *stream, *plainstream;
-    GMimeDataWrapper * wrapper;
-    GMimeSignatureValidity *result;
+    GMimeStream *stream;
+    GMimeStream *plainstream;
+    GMimeDataWrapper *wrapper;
+    GMimeGpgmeSigstat *result;
     gchar *headbuf = g_malloc0(1024);
 
     g_return_val_if_fail(GMIME_IS_PART(part), NULL);
-    g_return_val_if_fail(GMIME_IS_GPGME_CONTEXT(ctx), NULL);
-    g_return_val_if_fail(GMIME_CIPHER_CONTEXT(ctx)->encrypt_protocol !=
-			 NULL, NULL);
 
     /* get the raw content */
     wrapper = g_mime_part_get_content_object(part);
@@ -284,8 +314,8 @@ g_mime_part_rfc2440_decrypt(GMimePart * part,
 
     /* decrypt and (if possible) verify the input */
     result =
-	g_mime_cipher_context_decrypt(GMIME_CIPHER_CONTEXT(ctx), stream,
-			      plainstream, err);
+	libbalsa_gpgme_decrypt(stream, plainstream, GPGME_PROTOCOL_OpenPGP,
+			       parent, err);
 
     if (result != NULL) {
 	GMimeStream *filter_stream;
@@ -296,7 +326,8 @@ g_mime_part_rfc2440_decrypt(GMimePart * part,
 	/* strip crlf off encrypted stuff coming from Winbloze crap */
 	filter_stream = g_mime_stream_filter_new(plainstream);
 	filter = g_mime_filter_crlf_new(FALSE, FALSE);
-	g_mime_stream_filter_add(GMIME_STREAM_FILTER(filter_stream), filter);
+	g_mime_stream_filter_add(GMIME_STREAM_FILTER(filter_stream),
+				 filter);
 	g_object_unref(filter);
 
 	/* replace the old contents by the decrypted stuff */
@@ -307,14 +338,15 @@ g_mime_part_rfc2440_decrypt(GMimePart * part,
 	g_mime_stream_write_to_stream(filter_stream, out_stream);
 	g_object_unref(filter_stream);
 
-	g_mime_part_set_content_encoding(part, GMIME_CONTENT_ENCODING_8BIT);
+	g_mime_part_set_content_encoding(part,
+					 GMIME_CONTENT_ENCODING_8BIT);
 
 	/*
- 	 * Set the charset of the decrypted content to the RFC 2440 "Charset:"
- 	 * header. If it is not present, RFC 2440 defines that the contents
- 	 * should be utf-8, but real-life applications (e.g. pgp4pine) tend to
- 	 * use "some" charset, so "unknown-8bit" is a safe choice in this case
- 	 * and if no other charset is given.
+	 * Set the charset of the decrypted content to the RFC 2440
+	 * "Charset:" header.  If it is not present, RFC 2440 defines that
+	 * the contents should be utf-8, but real-life applications (e.g.
+	 * pgp4pine) tend to use "some" charset, so "unknown-8bit" is a
+	 * safe choice in this case and if no other charset is given.
 	 */
 	if (g_mime_object_get_content_type(GMIME_OBJECT(part))) {
  	    gchar *up_headbuf = g_ascii_strup(headbuf, -1);
@@ -328,13 +360,17 @@ g_mime_part_rfc2440_decrypt(GMimePart * part,
  		while (*line_end > ' ')
  		    line_end++;
  		*line_end = '\0';
-		g_mime_object_set_content_type_parameter(GMIME_OBJECT(part),
-							 "charset", p);
+		g_mime_object_set_content_type_parameter(GMIME_OBJECT
+							 (part), "charset",
+							 p);
  	    } else {
-		if (!g_ascii_strcasecmp("us-ascii",
-			 g_mime_object_get_content_type_parameter(GMIME_OBJECT(part),
+		if (!g_ascii_strcasecmp
+		    ("us-ascii",
+		     g_mime_object_get_content_type_parameter(GMIME_OBJECT
+							      (part),
 								  "charset")))
-		    g_mime_object_set_content_type_parameter(GMIME_OBJECT(part),
+		    g_mime_object_set_content_type_parameter(GMIME_OBJECT
+							     (part),
 							     "charset",
 							     "unknown-8bit");
 	    }
