@@ -23,14 +23,14 @@
 #ifndef __LIBBALSA_IDENTITY_H__
 #define __LIBBALSA_IDENTITY_H__
 
-#include "config.h"
+#ifndef BALSA_VERSION
+# error "Include config.h before this file."
+#endif
 
 #include <gtk/gtk.h>
 #include <gmime/internet-address.h>
 
-#if ENABLE_ESMTP
-#include "smtp-server.h"
-#endif
+#include "libbalsa.h"
 
 #ifdef __cpluscplus
 extern "C" 
@@ -52,7 +52,6 @@ extern "C"
 #define LIBBALSA_IS_IDENTITY_CLASS(klass) \
     (G_TYPE_CHECK_CLASS_TYPE (klass, LIBBALSA_TYPE_IDENTITY))
 
-    typedef struct _LibBalsaIdentity LibBalsaIdentity;
     typedef struct _LibBalsaIdentityClass LibBalsaIdentityClass;
     
     
@@ -81,14 +80,12 @@ extern "C"
         gchar *x_face;
 	gboolean request_mdn;
 
-#ifdef HAVE_GPGME
 	gboolean gpg_sign;
 	gboolean gpg_encrypt;
 	gboolean always_trust;
 	gboolean warn_send_plain;
 	gint crypt_protocol;
         gchar *force_key_id;
-#endif
 #if ENABLE_ESMTP
 	LibBalsaSmtpServer *smtp_server;
 #endif                          /* ENABLE_ESMTP */
@@ -127,11 +124,9 @@ extern "C"
                                            smtp_server);
 #endif                          /* ENABLE_ESMTP */
 
-#ifdef HAVE_GPGME
     void libbalsa_identity_set_gpg_sign(LibBalsaIdentity*, gboolean);
     void libbalsa_identity_set_gpg_encrypt(LibBalsaIdentity*, gboolean);
     void libbalsa_identity_set_crypt_protocol(LibBalsaIdentity* ident, gint);
-#endif
 
     void libbalsa_identity_config_dialog(GtkWindow * parent,
                                          GList ** identities,
