@@ -233,18 +233,16 @@ libbalsa_imap_server_init(LibBalsaImapServer * imap_server)
 static void
 libbalsa_imap_server_finalize(GObject * object)
 {
-    LibBalsaServer *server;
     LibBalsaImapServer *imap_server;
 
     g_return_if_fail(LIBBALSA_IS_IMAP_SERVER(object));
 
-    server = LIBBALSA_SERVER(object);
     imap_server = LIBBALSA_IMAP_SERVER(object);
 
     LOCK_SERVERS();
     g_hash_table_remove(imap_servers, imap_server->key);
     UNLOCK_SERVERS();
-    
+
     g_source_remove(imap_server->connection_cleanup_id);
 
 #if 0
@@ -661,7 +659,7 @@ libbalsa_imap_server_get_handle(LibBalsaImapServer *imap_server, GError **err)
     struct handle_info *info = NULL;
     ImapResult rc;
 
-    if (imap_server->offline_mode)
+    if (!imap_server || imap_server->offline_mode)
         return NULL;
 
     LOCK_SERVER(imap_server);
