@@ -63,6 +63,7 @@ typedef enum
   IMCAP_AGSSAPI,		/* RFC 1731: GSSAPI authentication */
   IMCAP_APLAIN,                 /* RFC 2595: */
   IMCAP_ACL,			/* RFC 2086: IMAP4 ACL extension */
+  IMCAP_RIGHTS,                 /* RFC 4314: IMAP4 RIGHTS= extension */
   IMCAP_BINARY,                 /* RFC 3516 */
   IMCAP_CHILDREN,               /* RFC 3348 */
   IMCAP_COMPRESS_DEFLATE,       /* RFC 4978 */
@@ -72,6 +73,7 @@ typedef enum
   IMCAP_LOGINDISABLED,		/* RFC 2595 */
   IMCAP_MULTIAPPEND,            /* RFC 3502 */
   IMCAP_NAMESPACE,              /* RFC 2342: IMAP4 Namespace */
+  IMCAP_QUOTA,                  /* RFC 2087 */
   IMCAP_SASLIR,                 /* RFC 4959 */
   IMCAP_SCAN,                   /* FIXME: RFC? */
   IMCAP_STARTTLS,		/* RFC 2595: STARTTLS */
@@ -152,8 +154,9 @@ void imap_mbox_handle_connect_notify(ImapMboxHandle* handle,
 
 void imap_mbox_handle_destroy(ImapMboxHandle* handle);
 
-ImapResponse imap_mbox_handle_fetch(ImapMboxHandle* handle, const gchar *seq, 
-                                    const gchar* headers[]);
+ImapResponse imap_mbox_handle_fetch_unlocked(ImapMboxHandle* handle,
+                                             const gchar *seq, 
+                                             const gchar* headers[]);
 ImapResponse imap_mbox_handle_fetch_env(ImapMboxHandle* handle,
                                         const gchar *seq);
 
