@@ -27,6 +27,7 @@
 #include <ctype.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
 #if defined(USE_TLS)
 #include <openssl/ssl.h>
@@ -176,7 +177,7 @@ pop_check_status(PopHandle *pop, GError **err)
     pop->state = IMHS_DISCONNECTED;
     sio_detach(pop->sio); pop->sio = NULL; close(pop->sd);
     g_set_error(err, IMAP_ERROR, IMAP_POP_SEVERED_ERROR,
-                "POP3 Connection severed");
+                "POP3 connection severed");
     return FALSE;
   }
      
@@ -390,7 +391,7 @@ pop_authenticate(PopHandle *pop, const char *greeting, GError **err)
   const PopAuthenticator *authenticator;
   ImapResult r;
 
-  if(g_strncasecmp(greeting, "+OK", 3) != 0) {
+  if(g_ascii_strncasecmp(greeting, "+OK", 3) != 0) {
     g_set_error(err, IMAP_ERROR, IMAP_POP_AUTH_ERROR,
                 "Server does not welcome us: %s", greeting);
     return FALSE;
@@ -725,7 +726,8 @@ pop_complete_retr(PopHandle *pop, PopAsyncCb cb, void *arg)
   if(cb)
     cb(rc, arg, &err);
   if(resp) { /* same code as in fetch_message() */
-    while( sio_gets(pop->sio, line, sizeof(line)) &&
+    char * str;
+    while( (str = sio_gets(pop->sio, line, sizeof(line))) &&
            strcmp(line, ".\r\n") ) {
       char *buf = line[0] == '.' ? line+1 : line;
       unsigned len = strlen(buf);
@@ -734,8 +736,18 @@ pop_complete_retr(PopHandle *pop, PopAsyncCb cb, void *arg)
       if(cb) 
         cb(POP_REQ_DATA, arg, len, buf);
     }
-    if(cb)
-      cb(POP_REQ_DONE, arg, err);
+    if(!str) {/* Unexpected end of data */
+      pop->state = IMHS_DISCONNECTED;
+      sio_detach(pop->sio); pop->sio = NULL; close(pop->sd);
+      g_set_error(&err, IMAP_ERROR, IMAP_POP_SEVERED_ERROR,
+                "POP3 connection severed");
+      
+      if(cb)
+        cb(POP_REQ_ERR, arg, &err);
+    } else {
+      if(cb)
+        cb(POP_REQ_DONE, arg);
+    }
   }
 
   g_clear_error(&err);
