@@ -20,69 +20,12 @@
  * 02111-1307, USA.
  */
 
-#include <string.h>
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
 #include "libbalsa-conf.h"
 
-#if !GLIB_CHECK_VERSION(2, 6, 0)
-
-#define BALSA_CONFIG_PREFIX "balsa/"
-
-/* 
- * Call @func for each section name that begins with @prefix.
- * @func is called with arguments:
- *   const gchar * @key		the section;
- *   const gchar * @value	the trailing part of the section name,
- *   				following the @prefix;
- *   gpointer @data		the @data passed in.
- * Iteration terminates when @func returns TRUE.
- */
-void
-libbalsa_conf_foreach_group(const gchar * prefix,
-                            LibBalsaConfForeachFunc func, gpointer data)
-{
-    gsize pref_len;
-    void *iterator;
-    gchar *key;
-
-    pref_len = strlen(prefix);
-    iterator = gnome_config_init_iterator_sections(BALSA_CONFIG_PREFIX);
-    while ((iterator = gnome_config_iterator_next(iterator, &key, NULL))) {
-        if (strncmp(key, prefix, pref_len) == 0
-            && func(key, key + pref_len, data)) {
-            g_free(key);
-            g_free(iterator);
-            break;
-        }
-        g_free(key);
-    }
-}
-
-void
-libbalsa_conf_push_group(const char *group)
-{
-    gchar *prefix = g_strconcat(BALSA_CONFIG_PREFIX, group, "/", NULL);
-    gnome_config_push_prefix(prefix);
-    g_free(prefix);
-}
-
-void
-libbalsa_conf_remove_group_(const char *group, gboolean priv)
-{
-    gchar *prefix = g_strconcat(BALSA_CONFIG_PREFIX, group, "/", NULL);
-    gnome_config_clean_section_(prefix, priv);
-    g_free(prefix);
-}
-
-gboolean
-libbalsa_conf_has_group(const char *group)
-{
-    gchar *prefix = g_strconcat(BALSA_CONFIG_PREFIX, group, "/", NULL);
-    gboolean retval = gnome_config_has_section(prefix);
-    g_free(prefix);
-    return retval;
-}
-
-#else                           /* !GLIB_CHECK_VERSION(2, 6, 0) */
+#include <string.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -98,9 +41,6 @@ libbalsa_conf_has_group(const char *group)
 typedef struct {
     GKeyFile *key_file;
     gchar *path;
-#if !GLIB_CHECK_VERSION(2, 7, 0)
-    gchar *new_path;
-#endif                          /* !GLIB_CHECK_VERSION(2, 7, 0) */
     guint changes;
     time_t mtime;
 } LibBalsaConf;
@@ -142,23 +82,27 @@ lbc_init(LibBalsaConf * conf, const gchar * filename,
          const gchar * old_dir)
 {
     struct stat buf;
-    GError *error;
+    GError *error = NULL;
+    gint rc;
 
     if (!conf->path)
         conf->path =
             g_build_filename(g_get_home_dir(), ".balsa", filename, NULL);
+    rc = stat(conf->path, &buf);
     if (conf->key_file) {
-        if (stat(conf->path, &buf) < 0 || buf.st_mtime <= conf->mtime)
+        if (rc >= 0 && buf.st_mtime <= conf->mtime)
+            /* found the config file, and it hasn't been touched since
+             * we loaded it */
             return;
-        conf->mtime = buf.st_mtime;
-    } else
+    } else {
         conf->key_file = g_key_file_new();
+        if (rc < 0)
+            /* no config file--must be first time startup */
+            return;
+    }
+    conf->mtime = buf.st_mtime;
 
-#if !GLIB_CHECK_VERSION(2, 7, 0)
-    conf->new_path = g_strconcat(conf->path, ".new", NULL);
-#endif                          /* !GLIB_CHECK_VERSION(2, 7, 0) */
     libbalsa_assure_balsa_dir();
-    error = NULL;
     if (!g_key_file_load_from_file
         (conf->key_file, conf->path, G_KEY_FILE_NONE, &error)) {
         gchar *old_path;
@@ -171,8 +115,7 @@ lbc_init(LibBalsaConf * conf, const gchar * filename,
         g_message("Could not load config from \"%s\":\n %s\n"
                   " trying \"%s\"", conf->path, error->message, old_path);
 #endif                          /* DEBUG */
-        g_error_free(error);
-        error = NULL;
+        g_clear_error(&error);
 
         buf = lbc_readfile(old_path);
         if (buf) {
@@ -191,20 +134,15 @@ lbc_init(LibBalsaConf * conf, const gchar * filename,
                       old_path,
                       error ? error->message : g_strerror(errno));
 #endif                          /* DEBUG */
-            if (error) {
-                g_error_free(error);
-                error = NULL;
-            }
+            g_clear_error(&error);
             warn = FALSE;
         }
         g_free(old_path);
-        if (warn) {
+        if (warn)
             libbalsa_information(LIBBALSA_INFORMATION_WARNING,
                                  _("Your Balsa configuration "
                                    "is now stored in "
                                    "\"~/.balsa/config\"."));
-            warn = FALSE;
-        }
     }
 }
 
@@ -424,19 +362,9 @@ libbalsa_conf_get_double_with_default_(const char *path,
     GError *error = NULL;
 
     key = lbc_get_key(path, &defval);
-#if GLIB_CHECK_VERSION(2, 12, 0)
     retval =
         g_key_file_get_double(LBC_KEY_FILE(priv), lbc_groups->data, key,
 			      &error);
-#else
-    {
-	gchar *s =
-	    g_key_file_get_string(LBC_KEY_FILE(priv), lbc_groups->data, key,
-				  &error);
-	retval = atof(s);
-	g_free(s);
-    }
-#endif
     g_free(key);
     if (error) {
         g_error_free(error);
@@ -461,15 +389,8 @@ libbalsa_conf_set_int_(const char *path, int value, gboolean priv)
 void
 libbalsa_conf_set_double_(const char *path, double value, gboolean priv)
 {
-#if GLIB_CHECK_VERSION(2, 12, 0)
     g_key_file_set_double(LBC_KEY_FILE(priv), lbc_groups->data, path,
 			  value);
-#else
-    char buffer[20];
-    snprintf(buffer, sizeof(buffer), "%19g", value);
-    g_key_file_set_string(LBC_KEY_FILE(priv), lbc_groups->data, path,
-                          buffer);
-#endif
     LBC_CHANGED(priv);
 }
 
@@ -541,10 +462,6 @@ lbc_drop_all(LibBalsaConf * conf)
     conf->key_file = NULL;
     g_free(conf->path);
     conf->path = NULL;
-#if !GLIB_CHECK_VERSION(2, 7, 0)
-    g_free(conf->new_path);
-    conf->new_path = NULL;
-#endif                          /* !GLIB_CHECK_VERSION(2, 7, 0) */
     conf->changes = 0;
 }
 
@@ -560,27 +477,13 @@ libbalsa_conf_drop_all(void)
 static void
 lbc_sync(LibBalsaConf * conf)
 {
-    gchar **groups;
     gchar *buf;
     gsize len;
-    GError *error;
-#if !GLIB_CHECK_VERSION(2, 7, 0)
-    gint fd;
-#endif                          /* !GLIB_CHECK_VERSION(2, 7, 0) */
+    GError *error = NULL;
 
     if (!conf->changes)
         return;
 
-    groups = g_key_file_get_groups(conf->key_file, NULL);
-    if (*groups) {
-        gchar **group;
-
-        for (group = &groups[1]; *group; group++)
-            g_key_file_set_comment(conf->key_file, *group, NULL, "", NULL);
-    }
-    g_strfreev(groups);
-
-    error = NULL;
     buf = g_key_file_to_data(conf->key_file, &len, &error);
     if (error) {
 #if DEBUG
@@ -592,7 +495,7 @@ lbc_sync(LibBalsaConf * conf)
         return;
     }
 
-#if GLIB_CHECK_VERSION(2, 7, 0)
+    conf->mtime = time(NULL);
     if (!g_file_set_contents(conf->path, buf, len, &error)) {
         if (error) {
 #if DEBUG
@@ -609,50 +512,6 @@ lbc_sync(LibBalsaConf * conf)
     }
 
     g_free(buf);
-#else                           /* GLIB_CHECK_VERSION(2, 7, 0) */
-    fd = g_open(conf->new_path, O_WRONLY | O_CREAT | O_TRUNC,
-                S_IRUSR | S_IWUSR);
-    if (fd < 0) {
-#if DEBUG
-        g_message("Failed to open temporary config file \"%s\"\n"
-                  " changes not saved", conf->new_path);
-#endif                          /* DEBUG */
-        g_free(buf);
-        return;
-    }
-
-    if (write(fd, buf, len) < (gssize) len) {
-#if DEBUG
-        g_message("Failed to write temporary config file \"%s\"\n"
-                  " changes not saved", conf->new_path);
-#endif                          /* DEBUG */
-        close(fd);
-        g_unlink(conf->new_path);
-        g_free(buf);
-        return;
-    }
-    close(fd);
-    g_free(buf);
-
-    if (g_unlink(conf->path) < 0
-        && g_file_error_from_errno(errno) != G_FILE_ERROR_NOENT) {
-#if DEBUG
-        g_message("Failed to unlink config file \"%s\"\n"
-                  " new config file saved as \"%s\"", conf->path,
-                  conf->new_path);
-        perror("Config");
-#endif                          /* DEBUG */
-        return;
-    }
-
-    if (g_rename(conf->new_path, conf->path) < 0) {
-#if DEBUG
-        g_message("Failed to rename temporary config file \"%s\"\n",
-                  conf->new_path);
-#endif                          /* DEBUG */
-        return;
-    }
-#endif                          /* GLIB_CHECK_VERSION(2, 7, 0) */
 }
 
 void
@@ -663,5 +522,3 @@ libbalsa_conf_sync(void)
     lbc_sync(&lbc_conf_priv);
     lbc_unlock();
 }
-
-#endif                          /* !GLIB_CHECK_VERSION(2, 6, 0) */
