@@ -27,14 +27,17 @@
  * Author : Emmanuel Allaud
  */
 
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
+
 #include <string.h>
 
 #include "filter-file.h"
 #include "libbalsa-conf.h"
 #include "mailbox-filter.h"
 #include "misc.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 
 /* Returns a slist of filters having the corresponding when field
  * There is no copy, the new list references object of the source list
