@@ -77,6 +77,12 @@ gboolean libbalsa_imap_rename_subfolder(LibBalsaMailboxImap* mbox,
 gboolean libbalsa_imap_delete_folder(LibBalsaMailboxImap * mailbox,
                                      GError **err);
 
+gboolean libbalsa_imap_get_quota(LibBalsaMailboxImap * mailbox,
+                                 gulong *max_kbyte, gulong *used_kbyte);
+
+gchar *libbalsa_imap_get_rights(LibBalsaMailboxImap * mailbox);
+gchar **libbalsa_imap_get_acls(LibBalsaMailboxImap * mailbox);
+
 gchar *libbalsa_imap_url(LibBalsaServer * server, const gchar * path);
 
 void libbalsa_imap_set_cache_size(off_t cache_size);
