@@ -20,10 +20,10 @@
  * 02111-1307, USA.
  */
 
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
 
-#define _XOPEN_SOURCE          500
-#define _XOPEN_SOURCE_EXTENDED 1
 
 #include <unistd.h>
 #include <fcntl.h>
@@ -37,7 +37,7 @@
 #include "misc.h"
 #include "libbalsa_private.h"
 #include "mime-stream-shared.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 
 struct message_info {
     LibBalsaMailboxLocalMessageInfo local_info;
@@ -72,7 +72,8 @@ static void libbalsa_mailbox_maildir_load_config(LibBalsaMailbox * mailbox,
 
 static GMimeStream *libbalsa_mailbox_maildir_get_message_stream(LibBalsaMailbox *
 							   mailbox,
-							   guint msgno);
+								guint msgno,
+								gboolean peek);
 
 static gboolean libbalsa_mailbox_maildir_open(LibBalsaMailbox * mailbox,
 					      GError **err);
@@ -86,11 +87,10 @@ static gboolean
 libbalsa_mailbox_maildir_fetch_message_structure(LibBalsaMailbox * mailbox,
 						 LibBalsaMessage * message,
 						 LibBalsaFetchFlag flags);
-static gboolean libbalsa_mailbox_maildir_add_message(LibBalsaMailbox *
-                                                     mailbox,
-                                                     GMimeStream * stream,
-                                                     LibBalsaMessageFlag
-                                                     flags, GError ** err);
+static guint libbalsa_mailbox_maildir_add_messages(LibBalsaMailbox *
+						   mailbox,
+						   LibBalsaAddMessageIterator m,
+						   void *m_arg, GError ** err);
 static guint
 libbalsa_mailbox_maildir_total_messages(LibBalsaMailbox * mailbox);
 
@@ -167,7 +167,8 @@ libbalsa_mailbox_maildir_class_init(LibBalsaMailboxMaildirClass * klass)
 	libbalsa_mailbox_maildir_close_mailbox;
     libbalsa_mailbox_class->fetch_message_structure =
 	libbalsa_mailbox_maildir_fetch_message_structure;
-    libbalsa_mailbox_class->add_message = libbalsa_mailbox_maildir_add_message;
+    libbalsa_mailbox_class->add_messages =
+	libbalsa_mailbox_maildir_add_messages;
     libbalsa_mailbox_class->total_messages =
 	libbalsa_mailbox_maildir_total_messages;
 
@@ -311,7 +312,7 @@ libbalsa_mailbox_maildir_load_config(LibBalsaMailbox * mailbox,
 
 static GMimeStream *
 libbalsa_mailbox_maildir_get_message_stream(LibBalsaMailbox * mailbox,
-					    guint msgno)
+					    guint msgno, gboolean peek)
 {
     struct message_info *msg_info;
 
@@ -464,6 +465,11 @@ lbm_maildir_parse_subdirs(LibBalsaMailboxMaildir * mdir)
     }
 
     lbm_maildir_parse(mdir, "cur", &fileno);
+    /* We parse "new" after "cur", so that any recent messages will have
+     * higher msgnos than any current messages. That ensures that the
+     * message tree saved by LibBalsaMailboxLocal is still valid, and
+     * that the new messages will be inserted correctly into the tree by
+     * libbalsa_mailbox_local_add_messages. */
     lbm_maildir_parse(mdir, "new", &fileno);
 }
 
@@ -556,7 +562,7 @@ libbalsa_mailbox_maildir_check(LibBalsaMailbox * mailbox)
 	libbalsa_mailbox_set_mtime(mailbox, st.st_mtime);
         return;
     }
-    if (st.st_mtime <= mtime)
+    if (st.st_mtime == mtime)
 	return;
 
     libbalsa_mailbox_set_mtime(mailbox, st.st_mtime);
@@ -777,7 +783,7 @@ libbalsa_mailbox_maildir_sync(LibBalsaMailbox * mailbox, gboolean expunge)
 	    msg_info->local_info.flags &= ~LIBBALSA_MESSAGE_FLAG_RECENT;
 	if (((msg_info->local_info.flags & LIBBALSA_MESSAGE_FLAG_RECENT)
              && strcmp(msg_info->subdir, "new") != 0)
-            || ((!msg_info->local_info.flags & LIBBALSA_MESSAGE_FLAG_RECENT)
+            || (!(msg_info->local_info.flags & LIBBALSA_MESSAGE_FLAG_RECENT)
                 && strcmp(msg_info->subdir, "cur") != 0)
             || FLAGS_CHANGED(msg_info)) {
 	    if (!maildir_sync_add(msg_info, path))
@@ -815,6 +821,7 @@ libbalsa_mailbox_maildir_sync(LibBalsaMailbox * mailbox, gboolean expunge)
 
         /* Reparse, to get the fileno entries right. */
         lbm_maildir_parse_subdirs(mdir);
+        mailbox->msg_tree_changed = TRUE;
 
         if (stat(mdir->tmpdir, &st) == 0)
             libbalsa_mailbox_set_mtime(mailbox, st.st_mtime);
@@ -894,7 +901,6 @@ libbalsa_mailbox_maildir_add_message(LibBalsaMailbox * mailbox,
     char *new_filename;
     struct message_info *msg_info;
     gint retval;
-    LibBalsaMailboxMaildir *mdir;
     time_t mtime;
 
     /* open tempfile */
@@ -904,10 +910,10 @@ libbalsa_mailbox_maildir_add_message(LibBalsaMailbox * mailbox,
 	return FALSE;
     out_stream = g_mime_stream_fs_new(fd);
 
-    in_stream = g_mime_stream_filter_new_with_stream(stream);
+    in_stream = g_mime_stream_filter_new(stream);
     crlffilter =
-        g_mime_filter_crlf_new(GMIME_FILTER_CRLF_DECODE,
-                               GMIME_FILTER_CRLF_MODE_CRLF_ONLY);
+        g_mime_filter_crlf_new(FALSE,
+                               FALSE);
     g_mime_stream_filter_add(GMIME_STREAM_FILTER(in_stream), crlffilter);
     g_object_unref(crlffilter);
  
@@ -940,7 +946,6 @@ libbalsa_mailbox_maildir_add_message(LibBalsaMailbox * mailbox,
     free_message_info(msg_info);
     g_free(tmp);
 
-    mdir = (LibBalsaMailboxMaildir *) mailbox;
     if ((mtime = libbalsa_mailbox_get_mtime(mailbox)) != 0)
 	/* If we checked or synced the mailbox less than 1 second ago,
 	 * the cached modification time could be the same as the new
@@ -950,6 +955,27 @@ libbalsa_mailbox_maildir_add_message(LibBalsaMailbox * mailbox,
     return retval;
 }
 
+static guint
+libbalsa_mailbox_maildir_add_messages(LibBalsaMailbox * mailbox,
+				      LibBalsaAddMessageIterator msg_iterator,
+				      void *arg,
+				      GError **err)
+{
+    LibBalsaMessageFlag flag;
+    GMimeStream *stream;
+
+    guint cnt = 0;
+    while( msg_iterator(&flag, &stream, arg) ) {
+	gboolean success =
+	    libbalsa_mailbox_maildir_add_message(mailbox, stream, flag, err);
+	g_object_unref(stream);
+	if(!success)
+	    break;
+	cnt++;
+    }
+    return cnt;
+}
+
 static guint
 libbalsa_mailbox_maildir_total_messages(LibBalsaMailbox * mailbox)
 {
