@@ -20,10 +20,10 @@
  * 02111-1307, USA.
  */
 
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
 
-#define _XOPEN_SOURCE          500
-#define _XOPEN_SOURCE_EXTENDED 1
 /* to compile this on BSD/Darwin */
 #undef _POSIX_SOURCE
 
@@ -40,7 +40,7 @@
 #include "libbalsa_private.h"
 #include "libbalsa-conf.h"
 #include "mime-stream-shared.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 
 struct message_info {
     LibBalsaMailboxLocalMessageInfo local_info;
@@ -60,7 +60,8 @@ static void libbalsa_mailbox_mh_load_config(LibBalsaMailbox * mailbox,
 
 static GMimeStream *libbalsa_mailbox_mh_get_message_stream(LibBalsaMailbox *
 							   mailbox,
-							   guint msgno);
+							   guint msgno,
+							   gboolean peek);
 static gint lbm_mh_check_files(const gchar * path, gboolean create);
 static void lbm_mh_set_path(LibBalsaMailboxLocal * mailbox,
                             const gchar * path);
@@ -84,10 +85,10 @@ static gboolean libbalsa_mailbox_mh_fetch_message_structure(LibBalsaMailbox
                                                             * message,
                                                             LibBalsaFetchFlag
                                                             flags);
-static gboolean libbalsa_mailbox_mh_add_message(LibBalsaMailbox * mailbox,
-                                                GMimeStream * stream,
-                                                LibBalsaMessageFlag flags,
-                                                GError ** err);
+static guint libbalsa_mailbox_mh_add_messages(LibBalsaMailbox * mailbox,
+					      LibBalsaAddMessageIterator m,
+					      void *m_arg,
+					      GError ** err);
 static guint libbalsa_mailbox_mh_total_messages(LibBalsaMailbox * mailbox);
 
 
@@ -145,7 +146,7 @@ libbalsa_mailbox_mh_class_init(LibBalsaMailboxMhClass * klass)
 	libbalsa_mailbox_mh_close_mailbox;
     libbalsa_mailbox_class->fetch_message_structure =
 	libbalsa_mailbox_mh_fetch_message_structure;
-    libbalsa_mailbox_class->add_message = libbalsa_mailbox_mh_add_message;
+    libbalsa_mailbox_class->add_messages = libbalsa_mailbox_mh_add_messages;
     libbalsa_mailbox_class->total_messages =
 	libbalsa_mailbox_mh_total_messages;
 
@@ -264,7 +265,7 @@ libbalsa_mailbox_mh_load_config(LibBalsaMailbox * mailbox,
 
 static GMimeStream *
 libbalsa_mailbox_mh_get_message_stream(LibBalsaMailbox * mailbox,
-				       guint msgno)
+				       guint msgno, gboolean peek)
 {
     GMimeStream *stream;
     struct message_info *msg_info;
@@ -1093,9 +1094,9 @@ libbalsa_mailbox_mh_add_message(LibBalsaMailbox * mailbox,
     }
     out_stream = g_mime_stream_fs_new(fd);
 
-    crlffilter = g_mime_filter_crlf_new(GMIME_FILTER_CRLF_DECODE,
-                                        GMIME_FILTER_CRLF_MODE_CRLF_ONLY);
-    in_stream = g_mime_stream_filter_new_with_stream(stream);
+    crlffilter = g_mime_filter_crlf_new(FALSE,
+                                        FALSE);
+    in_stream = g_mime_stream_filter_new(stream);
     g_mime_stream_filter_add(GMIME_STREAM_FILTER(in_stream), crlffilter);
     g_object_unref(crlffilter);
 
@@ -1153,6 +1154,27 @@ libbalsa_mailbox_mh_add_message(LibBalsaMailbox * mailbox,
     return TRUE;
 }
 
+static guint
+libbalsa_mailbox_mh_add_messages(LibBalsaMailbox * mailbox,
+				 LibBalsaAddMessageIterator msg_iterator,
+				 void *arg,
+				 GError **err)
+{
+    LibBalsaMessageFlag flag;
+    GMimeStream *stream;
+
+    guint cnt = 0;
+    while( msg_iterator(&flag, &stream, arg) ) {
+	gboolean success =
+	    libbalsa_mailbox_mh_add_message(mailbox, stream, flag, err);
+	g_object_unref(stream);
+	if(!success)
+	    break;
+	cnt++;
+    }
+    return cnt;
+}
+
 static guint
 libbalsa_mailbox_mh_total_messages(LibBalsaMailbox * mailbox)
 {
