@@ -22,6 +22,10 @@
 #ifndef __LIBBALSA_MESSAGE_H__
 #define __LIBBALSA_MESSAGE_H__
 
+#ifndef BALSA_VERSION
+# error "Include config.h before this file."
+#endif
+
 #include <glib.h>
 
 #include <stdio.h>
@@ -29,7 +33,6 @@
 
 #include <gmime/gmime.h>
 
-#include "config.h"
 #ifdef HAVE_GPGME
 #include "rfc3156.h"
 #endif
@@ -139,14 +142,14 @@ struct _LibBalsaMessageHeaders {
     gchar *subject;
 
     /* from, reply, and disposition notification addresses */
-    LibBalsaAddress *from;
-    LibBalsaAddress *reply_to;
-    LibBalsaAddress *dispnotify_to;
+    InternetAddressList *from;
+    InternetAddressList *reply_to;
+    InternetAddressList *dispnotify_to;
 
     /* primary, secondary, and blind recipent lists */
-    GList *to_list;
-    GList *cc_list;
-    GList *bcc_list;
+    InternetAddressList *to_list;
+    InternetAddressList *cc_list;
+    InternetAddressList *bcc_list;
 
     /* Mime type */
     GMimeContentType *content_type;
@@ -178,7 +181,7 @@ struct _LibBalsaMessage {
     GMimeMessage *mime_msg;
 
     /* sender address */
-    LibBalsaAddress *sender;
+    InternetAddressList *sender;
 
     /* subject line; we still need it here for sending;
      * although _SET_SUBJECT might resolve it(?) 
@@ -191,8 +194,6 @@ struct _LibBalsaMessage {
 #else
 #define LIBBALSA_MESSAGE_GET_SUBJECT(m) libbalsa_message_get_subject(m)
 #endif
-#define LIBBALSA_MESSAGE_SET_SUBJECT(m,s) \
-        do { g_free((m)->subj); (m)->subj = (s); } while (0)
 
     /* replied message ID's */
     GList *references;
@@ -209,6 +210,9 @@ struct _LibBalsaMessage {
 
     /* protection (i.e. sign/encrypt) status (received message) */
     LibBalsaMsgProtectState prot_state;
+
+    /* forced id of the senders secret key, empty to choose it from the mail address */
+    gchar * force_key_id;
 #endif
 
     /* a forced multipart subtype or NULL for mixed; used only for
@@ -234,6 +238,8 @@ struct _LibBalsaMessage {
 #define LIBBALSA_MESSAGE_GET_NO(m)  libbalsa_message_get_no(m)
 #endif
 
+    gchar *tempdir;     /* to hold named parts */
+
     unsigned has_all_headers:1;
 };
 
@@ -281,14 +287,7 @@ LibBalsaMessage *libbalsa_message_new(void);
 gboolean libbalsa_message_save(LibBalsaMessage * message,
 			       const gchar *filename);
 
-void libbalsa_messages_change_flag(GList * messages,
-                                   LibBalsaMessageFlag flag,
-                                   gboolean set);
-
 void libbalsa_message_reply(LibBalsaMessage * message);
-gboolean libbalsa_message_set_msg_flags(LibBalsaMessage * message,
-					LibBalsaMessageFlag set,
-					LibBalsaMessageFlag clear);
 
 void libbalsa_message_append_part(LibBalsaMessage * message,
 				  LibBalsaMessageBody * body);
@@ -297,19 +296,10 @@ gboolean libbalsa_message_body_ref(LibBalsaMessage * message, gboolean read,
                                    gboolean fetch_all_headers);
 void libbalsa_message_body_unref(LibBalsaMessage * message);
 
-gboolean libbalsa_message_postpone(LibBalsaMessage * message,
-				   LibBalsaMailbox * draftbox,
-				   LibBalsaMessage * reply_message,
-				   gchar * fcc, gint encoding, 
-				   gboolean flow);
-
 /*
  * misc message releated functions
  */
-gchar **libbalsa_create_hdr_pair(const gchar * name, gchar * value);
-
 const gchar *libbalsa_message_pathname(LibBalsaMessage * message);
-gchar *libbalsa_message_charset(LibBalsaMessage * message);
 const gchar *libbalsa_message_body_charset(LibBalsaMessageBody * body);
 gboolean libbalsa_message_is_multipart(LibBalsaMessage * message);
 gboolean libbalsa_message_is_partial(LibBalsaMessage * message,
@@ -320,14 +310,27 @@ gboolean libbalsa_message_is_pgp_signed(LibBalsaMessage * message);
 gboolean libbalsa_message_is_pgp_encrypted(LibBalsaMessage * message);
 #endif
 
-GList *libbalsa_message_find_user_hdr(LibBalsaMessage * message, 
-                                      const gchar * find);
-GMimeStream *libbalsa_message_get_part_by_id(LibBalsaMessage * message,
-                                             const gchar * id);
+const gchar* libbalsa_message_header_get_one(LibBalsaMessageHeaders* headers,
+                                             const gchar *find);
+GList* libbalsa_message_header_get_all(LibBalsaMessageHeaders* headers,
+                                       const gchar *find);
+const gchar *libbalsa_message_get_user_header(LibBalsaMessage * message,
+                                              const gchar * name);
+void libbalsa_message_set_user_header(LibBalsaMessage * message,
+                                      const gchar * name,
+                                      const gchar * value);
+
+LibBalsaMessageBody *libbalsa_message_get_part_by_id(LibBalsaMessage *
+                                                     message,
+                                                     const gchar * id);
 
 void libbalsa_message_set_dispnotify(LibBalsaMessage *message, 
-				     LibBalsaAddress *address);
+				     InternetAddress *ia);
 
+void libbalsa_message_set_subject(LibBalsaMessage * message,
+                                  const gchar * subject);
+void libbalsa_message_set_subject_from_header(LibBalsaMessage * message,
+                                              const gchar * header);
 /* use LIBBALSA_MESSAGE_GET_SUBJECT() macro, we may optimize this
    function out if we find a way.
 */
@@ -339,11 +342,13 @@ glong libbalsa_message_get_length(LibBalsaMessage* msg);
 glong libbalsa_message_get_no(LibBalsaMessage* msg);
 LibBalsaMessageAttach libbalsa_message_get_attach_icon(LibBalsaMessage *
 						       message);
-#define libbalsa_message_date_to_gchar(m, f) libbalsa_date_to_gchar(&(m)->headers->date, (f))
-#define libbalsa_message_headers_date_to_gchar(h, f) libbalsa_date_to_gchar(&(h)->date, (f))
+#define libbalsa_message_date_to_utf8(m, f) libbalsa_date_to_utf8(&(m)->headers->date, (f))
+#define libbalsa_message_headers_date_to_utf8(h, f) libbalsa_date_to_utf8(&(h)->date, (f))
 
 GList *libbalsa_message_refs_for_threading(LibBalsaMessage* msg);
 
+void libbalsa_message_load_envelope_from_stream(LibBalsaMessage * message,
+                                                GMimeStream * stream);
 void libbalsa_message_load_envelope(LibBalsaMessage *message);
 gboolean libbalsa_message_set_headers_from_string(LibBalsaMessage *message,
                                                   const gchar *str);
@@ -351,4 +356,12 @@ void libbalsa_message_set_references_from_string(LibBalsaMessage * message,
 						 const gchar *str);
 void libbalsa_message_set_in_reply_to_from_string(LibBalsaMessage * message,
 						  const gchar *str);
+GMimeStream *libbalsa_message_stream(LibBalsaMessage * message);
+gboolean libbalsa_message_copy(LibBalsaMessage * message,
+                               LibBalsaMailbox * dest, GError ** err);
+void libbalsa_message_change_flags(LibBalsaMessage * message,
+                                   LibBalsaMessageFlag set,
+                                   LibBalsaMessageFlag clear);
+
+const gchar *libbalsa_message_get_tempdir(LibBalsaMessage * message);
 #endif				/* __LIBBALSA_MESSAGE_H__ */
