@@ -51,10 +51,10 @@ process_mime_part(LibBalsaMessage * message, LibBalsaMessageBody * body,
                   gboolean flow)
 {
     gchar *res = NULL;
-    size_t allocated;
     GString *reply = NULL;
     gchar *mime_type;
     LibBalsaHTMLType html_type;
+    ssize_t allocated;
 
     switch (libbalsa_message_body_type(body)) {
     case LIBBALSA_MESSAGE_BODY_TYPE_OTHER:
@@ -78,10 +78,10 @@ process_mime_part(LibBalsaMessage * message, LibBalsaMessageBody * body,
 	if (ignore_html && html_type)
 	    break;
 
-	allocated = libbalsa_message_body_get_content(body, &res, NULL);
-	if (!res)
-	    return NULL;
 
+	allocated = libbalsa_message_body_get_content(body, &res, NULL);
+	if (!res || allocated == -1)
+	    return NULL;
 #ifdef HAVE_HTML_WIDGET
 	if (html_type) {
 	    allocated = libbalsa_html_filter(html_type, &res, allocated);
