@@ -23,6 +23,10 @@
 #ifndef __LIBBALSA_MISC_H__
 #define __LIBBALSA_MISC_H__
 
+#ifndef BALSA_VERSION
+# error "Include config.h before this file."
+#endif
+
 #include <stdio.h>
 #include <gtk/gtk.h>
 #include <gmime/gmime.h>
@@ -154,11 +158,7 @@ int libbalsa_safe_open (const char *path, int flags, mode_t mode, GError **err);
 int libbalsa_lock_file (const char *path, int fd, int excl, int dot, int timeout);
 int libbalsa_unlock_file (const char *path, int fd, int dot);
 int libbalsa_safe_rename (const char *src, const char *target);
-#if GLIB_CHECK_VERSION(2, 2, 0)
 #define libbalsa_str_has_prefix(str, prefix) g_str_has_prefix((str), (prefix))
-#else				/* GLIB_CHECK_VERSION(2, 2, 0) */
-gboolean libbalsa_str_has_prefix(const gchar * str, const gchar * prefix);
-#endif				/* GLIB_CHECK_VERSION(2, 2, 0) */
 
 gboolean libbalsa_ia_rfc2821_equal(const InternetAddress * a,
 				   const InternetAddress * b);
@@ -185,6 +185,8 @@ gboolean libbalsa_ldap_exists(const gchar *server);
 
 gboolean libbalsa_path_is_below_dir(const gchar * path, const gchar * dir);
 
+gchar *libbalsa_size_to_gchar(guint64 length);
+
 gchar * libbalsa_text_to_html(const gchar * title, const gchar * body, const gchar * lang);
 GString * libbalsa_html_encode_hyperlinks(GString * paragraph);
 
