@@ -24,6 +24,12 @@
 #ifndef __SEND_H__
 #define __SEND_H__
 
+#ifndef BALSA_VERSION
+# error "Include config.h before this file."
+#endif
+
+#include "libbalsa.h"
+
 typedef LibBalsaMailbox* (*LibBalsaFccboxFinder)(const gchar *url);
 typedef enum _LibBalsaMsgCreateResult LibBalsaMsgCreateResult;
 enum _LibBalsaMsgCreateResult {
@@ -39,6 +45,14 @@ enum _LibBalsaMsgCreateResult {
     LIBBALSA_MESSAGE_SERVER_ERROR
 };
 
+gboolean libbalsa_message_postpone(LibBalsaMessage * message,
+				   LibBalsaMailbox * draftbox,
+				   LibBalsaMessage * reply_message,
+				   gchar ** extra_headers,
+				   gboolean flow, 
+				   GError **error);
+
+
 #if ENABLE_ESMTP
 #include <libesmtp.h>
 
@@ -47,14 +61,16 @@ LibBalsaMsgCreateResult libbalsa_message_queue(LibBalsaMessage* message,
                                                LibBalsaMailbox* fccbox,
                                                LibBalsaSmtpServer *
                                                smtp_server,
-					       gboolean flow);
+					       gboolean flow,
+					       GError ** error);
 LibBalsaMsgCreateResult libbalsa_message_send(LibBalsaMessage * message,
                                               LibBalsaMailbox * outbox,
                                               LibBalsaMailbox * fccbox,
                                               LibBalsaFccboxFinder finder,
                                               LibBalsaSmtpServer *
                                               smtp_server, gboolean flow,
-                                              gboolean debug);
+                                              gboolean debug,
+					      GError ** error);
 gboolean libbalsa_process_queue(LibBalsaMailbox * outbox,
                                 LibBalsaFccboxFinder finder,
                                 GSList * smtp_servers, gboolean debug);
@@ -63,12 +79,14 @@ gboolean libbalsa_process_queue(LibBalsaMailbox * outbox,
 LibBalsaMsgCreateResult libbalsa_message_queue(LibBalsaMessage* message, 
 					       LibBalsaMailbox* outbox,
                                                LibBalsaMailbox* fccbox,
-					       gboolean flow);
+					       gboolean flow,
+					       GError ** error);
 LibBalsaMsgCreateResult libbalsa_message_send(LibBalsaMessage* message,
 					      LibBalsaMailbox* outbox,  
 					      LibBalsaMailbox* fccbox,
                                               LibBalsaFccboxFinder finder, 
-					      gboolean flow, gboolean debug);
+					      gboolean flow, gboolean debug,
+					      GError ** error);
 gboolean libbalsa_process_queue(LibBalsaMailbox* outbox, 
                                 LibBalsaFccboxFinder finder,
                                 gboolean debug);
@@ -89,7 +107,7 @@ typedef struct {
 } SendThreadMessage;
 
 #define  MSGSENDTHREAD(t_message, type, string, s_msg, s_mbox, messof) \
-  t_message = malloc( sizeof( SendThreadMessage )); \
+  t_message = g_new(SendThreadMessage, 1); \
   t_message->message_type = type; \
   strncpy(t_message->message_string, string, sizeof(t_message->message_string)); \
   t_message->msg = s_msg; \
