@@ -22,7 +22,9 @@
    in in a GtkText widget.
 */
 
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
 
 #include <stdio.h>
 
@@ -30,7 +32,8 @@
 #include "libbalsa.h"
 #include "libbalsa_private.h"
 #include "misc.h"
-#include "i18n.h"
+#include "macosx-helpers.h"
+#include <glib/gi18n.h>
 
 static void close_cb(GtkAction * action, gpointer data);
 static void copy_cb(GtkAction * action, gpointer data);
@@ -40,9 +43,9 @@ static void lsv_escape_cb(GtkAction * action, gpointer data);
 /* Normal items */
 static GtkActionEntry entries[] = {
     /* Top level */
-    {"FileMenu", NULL, "_File"},
-    {"EditMenu", NULL, "_Edit"},
-    {"ViewMenu", NULL, "_View"},
+    {"FileMenu", NULL, N_("_File")},
+    {"EditMenu", NULL, N_("_Edit")},
+    {"ViewMenu", NULL, N_("_View")},
     /* Items */
     {"Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
      N_("Close the window"), G_CALLBACK(close_cb)},
@@ -109,6 +112,8 @@ struct _LibBalsaSourceViewerInfo {
     GtkWidget *text;
     GtkWidget *window;
     gboolean *escape_specials;
+    gint *width;
+    gint *height;
 };
 
 typedef struct _LibBalsaSourceViewerInfo LibBalsaSourceViewerInfo;
@@ -154,7 +159,8 @@ lsv_escape_cb(GtkAction * action, gpointer data)
 			     _("Mailbox closed"));
 	return;
     }
-    msg_stream = libbalsa_mailbox_get_message_stream(msg->mailbox, msg->msgno);
+    msg_stream = libbalsa_mailbox_get_message_stream(msg->mailbox, msg->msgno,
+						     TRUE);
     if (msg_stream == NULL)
 	return;
 
@@ -192,11 +198,13 @@ lbsv_app_set_menus(GtkWindow * app, GtkAction ** action)
     GtkActionGroup *action_group;
     GtkUIManager *ui_manager;
     GtkAccelGroup *accel_group;
-    GError *error;
+    GError *error = NULL;
 
     window = GTK_WIDGET(app);
 
     action_group = gtk_action_group_new("MenuActions");
+    gtk_action_group_set_translation_domain(action_group, NULL);
+
     gtk_action_group_add_actions(action_group, entries,
                                  G_N_ELEMENTS(entries), window);
     gtk_action_group_add_toggle_actions(action_group, toggle_entries,
@@ -209,7 +217,6 @@ lbsv_app_set_menus(GtkWindow * app, GtkAction ** action)
     accel_group = gtk_ui_manager_get_accel_group(ui_manager);
     gtk_window_add_accel_group(GTK_WINDOW(window), accel_group);
 
-    error = NULL;
     if (!gtk_ui_manager_add_ui_from_string(ui_manager, ui_description,
                                            -1, &error)) {
         g_message("building menus failed: %s", error->message);
@@ -224,9 +231,24 @@ lbsv_app_set_menus(GtkWindow * app, GtkAction ** action)
     return menubar;
 }
 
+static void
+lsv_size_allocate_cb(GtkWindow * window, GtkAllocation * alloc,
+                     LibBalsaSourceViewerInfo * lsvi)
+{
+    GdkWindow *gdk_window;
+
+    if ((gdk_window = gtk_widget_get_window(lsvi->window))
+        && !(gdk_window_get_state(gdk_window)
+             & GDK_WINDOW_STATE_MAXIMIZED)) {
+        *lsvi->width  = alloc->width;
+        *lsvi->height = alloc->height;
+    }
+}
+
 void
 libbalsa_show_message_source(LibBalsaMessage* msg, const gchar * font,
-			     gboolean* escape_specials)
+			     gboolean* escape_specials,
+                             gint * width, gint * height)
 {
     GtkWidget *text;
     PangoFontDescription *desc;
@@ -234,6 +256,7 @@ libbalsa_show_message_source(LibBalsaMessage* msg, const gchar * font,
     GtkWidget *window;
     GtkAction *escape_action = NULL;
     LibBalsaSourceViewerInfo *lsvi;
+    GtkWidget *menubar;
 
     g_return_if_fail(msg);
     g_return_if_fail(MAILBOX_OPEN(msg->mailbox));
@@ -247,33 +270,42 @@ libbalsa_show_message_source(LibBalsaMessage* msg, const gchar * font,
     gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
     gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(text), GTK_WRAP_WORD_CHAR);
 
-    interior = gtk_scrolled_window_new(GTK_TEXT_VIEW(text)->hadjustment,
-                                       GTK_TEXT_VIEW(text)->vadjustment);
+    interior = gtk_scrolled_window_new(NULL, NULL);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(interior),
-                                   GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+                                   GTK_POLICY_AUTOMATIC,
+                                   GTK_POLICY_ALWAYS);
     gtk_container_add(GTK_CONTAINER(interior), GTK_WIDGET(text));
 
     window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title(GTK_WINDOW(window), _("Message Source"));
     g_object_set_data(G_OBJECT(window), "text", text);
     gtk_window_set_wmclass(GTK_WINDOW(window), "message-source", "Balsa");
-    gtk_window_set_default_size(GTK_WINDOW(window), 500, 400);
+    gtk_window_set_default_size(GTK_WINDOW(window), *width, *height);
     vbox = gtk_vbox_new(FALSE, 1);
-    gtk_box_pack_start(GTK_BOX(vbox), 
-                       lbsv_app_set_menus(GTK_WINDOW(window),
-                                          &escape_action), FALSE, TRUE, 1);
-    gtk_box_pack_start_defaults(GTK_BOX(vbox), interior);
+    menubar = lbsv_app_set_menus(GTK_WINDOW(window), &escape_action);
+    
+#if HAVE_MACOSX_DESKTOP
+    libbalsa_macosx_menu(window, GTK_MENU_SHELL(menubar));
+#else
+    gtk_box_pack_start(GTK_BOX(vbox), menubar, FALSE, TRUE, 1);
+#endif
+    
+    gtk_box_pack_start(GTK_BOX(vbox), interior, TRUE, TRUE, 0);
     gtk_container_add(GTK_CONTAINER(window), vbox);
 
     lsvi = g_new(LibBalsaSourceViewerInfo, 1);
-    lsvi->msg = msg;
-    g_object_ref(msg);
+    lsvi->msg = g_object_ref(msg);
     lsvi->text = text;
     lsvi->window = window;
     lsvi->escape_specials = escape_specials;
+    lsvi->width = width;
+    lsvi->height = height;
     g_object_set_data_full(G_OBJECT(window), "lsvi", lsvi,
                            (GDestroyNotify) lsv_window_destroy_notify);
 
+    g_signal_connect(window, "size-allocate",
+                     G_CALLBACK(lsv_size_allocate_cb), lsvi);
+
     gtk_widget_show_all(window);
     if (*escape_specials)
         gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(escape_action),
