@@ -19,6 +19,9 @@
  * 02111-1307, USA.
  */
 
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
 #include "assistant_init.h"
 
 #include <stdlib.h>
@@ -120,7 +123,9 @@ balsa_initdruid(GtkAssistant * assistant)
     balsa_druid_page_user(assistant, default_logo);
 #if !defined(ENABLE_TOUCH_UI)
     balsa_druid_page_directory(assistant, default_logo);
+#if HAVE_GNOME
     balsa_druid_page_defclient(assistant, default_logo);
+#endif
 #endif
     balsa_druid_page_finish(assistant, default_logo);
 }
@@ -137,14 +142,10 @@ dismiss_the_wizard(GtkWidget *wizard)
 void
 balsa_init_begin(void)
 {
-    static const int ASSISTANT_WIDTH = 800;
-    static const int ASSISTANT_HEIGHT = 640;
     GtkWidget *assistant;
 
     assistant = gtk_assistant_new();
     gtk_window_set_title(GTK_WINDOW(assistant), _("Configure Balsa"));
-    gtk_window_set_wmclass(GTK_WINDOW(assistant), "druid", "Balsa");
-    gtk_widget_set_size_request(assistant, ASSISTANT_WIDTH, ASSISTANT_HEIGHT);
 
     balsa_initdruid(GTK_ASSISTANT(assistant));
     gtk_widget_show_all(assistant);
