@@ -23,10 +23,15 @@
 
 #include "libbalsa.h"
 
+typedef void BalsaAddressBookCallback(LibBalsaAddressBook * address_book,
+                                      gboolean append);
 void balsa_address_book_config_new(LibBalsaAddressBook * address_book,
-                                   void (*cb) (LibBalsaAddressBook *
-                                               address_book,
-                                               gboolean append),
+				   BalsaAddressBookCallback callback,
                                    GtkWindow * parent);
+void balsa_address_book_config_new_from_type(GType type,
+                                             BalsaAddressBookCallback
+                                             callback, GtkWindow * parent);
+GtkWidget *balsa_address_book_add_menu(BalsaAddressBookCallback callback,
+                                       GtkWindow * parent);
 
 #endif				/* __ADDRESS_BOOK_CONFIG_H__ */
