@@ -20,9 +20,12 @@
  */
 
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
+#include "balsa-bonobo.h"
+
+#if HAVE_GNOME
 
 #include <string.h>
 
@@ -34,9 +37,6 @@
 #include "balsa-app.h"
 #include "sendmsg-window.h"
 
-#include "balsa-bonobo.h"
-
-
 static void balsa_composer_class_init (BalsaComposerClass *klass);
 static void balsa_composer_init (BalsaComposer *a);
 static void balsa_composer_object_finalize (GObject *object);
@@ -135,7 +135,7 @@ impl_balsa_composer_sendMessage (PortableServer_Servant _servant,
     guint i;
     
     gdk_threads_enter();
-    snd = sendmsg_window_compose(GTK_WIDGET(balsa_app.main_window));
+    snd = sendmsg_window_compose();
     gdk_threads_leave();
 
     if(strlen(to)) {
@@ -220,7 +220,7 @@ static void
 impl_balsa_application_checkmail (PortableServer_Servant _servant,
 				  CORBA_Environment * ev) {
     
-    check_new_messages_real (NULL, NULL, TYPE_CALLBACK);
+    check_new_messages_real (NULL, TYPE_CALLBACK);
 }
 
 static void
@@ -229,19 +229,21 @@ impl_balsa_application_openMailbox (PortableServer_Servant _servant,
 				    CORBA_Environment * ev) {
     gchar **urls = g_strsplit(name, ";", 20);
     g_idle_add((GSourceFunc) open_mailboxes_idle_cb, urls);
-    
+    gtk_window_present(GTK_WINDOW(balsa_app.main_window));
 }
 
 static void
 impl_balsa_application_openUnread (PortableServer_Servant _servant,
 				   CORBA_Environment * ev) {
     g_idle_add((GSourceFunc) initial_open_unread_mailboxes, NULL);
+    gtk_window_present(GTK_WINDOW(balsa_app.main_window));
 }
 
 static void
 impl_balsa_application_openInbox (PortableServer_Servant _servant,
 				  CORBA_Environment * ev) {
     initial_open_inbox();
+    gtk_window_present(GTK_WINDOW(balsa_app.main_window));
 }
 
 static void
@@ -274,3 +276,5 @@ BONOBO_TYPE_FUNC_FULL ( BalsaApplication,
 			GNOME_Balsa_Application,
 			BONOBO_TYPE_OBJECT,
 			balsa_application );
+
+#endif /* HAVE_GNOME */ 
