@@ -22,8 +22,11 @@
 #ifndef __BALSA_ICONS_H__
 #define __BALSA_ICONS_H__
 
+#ifndef BALSA_VERSION
+# error "Include config.h before this file."
+#endif
+
 #include <gtk/gtk.h>
-#include "config.h"
 
 #define BALSA_PIXMAP_ATTACHMENT			"balsa_attachment"
 #define BALSA_PIXMAP_COMPOSE			"balsa_compose"
@@ -90,11 +93,8 @@
 
 #define BALSA_PIXMAP_DROP_DOWN                  "balsa_drop_down"
 
-void register_balsa_pixmaps(void);
-void register_balsa_pixbufs(GtkWidget * widget);
-void balsa_icon_create(const gchar ** data, GdkPixmap ** pmap,
-                       GdkBitmap ** bmap);
-#if GTK_CHECK_VERSION(2, 8, 0)
+void balsa_register_pixmaps(void);
+void balsa_unregister_pixmaps(void);
+void balsa_register_pixbufs(GtkWidget * widget);
 const gchar * balsa_icon_id(const gchar * name);
-#endif                          /* GTK_CHECK_VERSION(2, 8, 0) */
 #endif
