@@ -22,8 +22,12 @@
 #ifndef __BALSA_MESSAGE_H__
 #define __BALSA_MESSAGE_H__
 
-#include <gnome.h>
+#ifndef BALSA_VERSION
+# error "Include config.h before this file."
+#endif
+
 #include "libbalsa.h"
+#include "balsa-app.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -31,9 +35,9 @@ extern "C" {
 
 
 #define BALSA_TYPE_MESSAGE          (balsa_message_get_type ())
-#define BALSA_MESSAGE(obj)          GTK_CHECK_CAST (obj, BALSA_TYPE_MESSAGE, BalsaMessage)
-#define BALSA_MESSAGE_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, BALSA_TYPE_MESSAGE, BalsaMessageClass)
-#define BALSA_IS_MESSAGE(obj)       GTK_CHECK_TYPE (obj, BALSA_TYPE_MESSAGE)
+#define BALSA_MESSAGE(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, BALSA_TYPE_MESSAGE, BalsaMessage)
+#define BALSA_MESSAGE_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, BALSA_TYPE_MESSAGE, BalsaMessageClass)
+#define BALSA_IS_MESSAGE(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, BALSA_TYPE_MESSAGE)
 
 
 typedef struct _BalsaMessage BalsaMessage;
@@ -57,7 +61,6 @@ struct _BalsaMessage {
 
 	/* header-related information */
 	ShownHeaders shown_headers;
-	gboolean show_all_headers;
 
 	/* Widgets to hold content */
         GtkWidget *cont_viewport;
@@ -73,12 +76,26 @@ struct _BalsaMessage {
 
         BalsaPartInfo *current_part;
         GtkWidget *parts_popup;
+        gboolean force_inline;
 
 	LibBalsaMessage *message;
 
 	gboolean close_with_msg;
 
         BalsaMessageFocusState focus_state;
+
+        /* Find-in-message stuff */
+        GtkWidget  *find_bar;
+        GtkWidget  *find_entry;
+        GtkWidget  *find_next;
+        GtkWidget  *find_prev;
+        GtkWidget  *find_sep;
+        GtkWidget  *find_label;
+        GtkTextIter find_iter;
+        gboolean    find_forward;
+
+        /* Tab position for headers */
+        gint tab_position;
 };
 
 struct _BalsaMessageClass {
@@ -87,19 +104,20 @@ struct _BalsaMessageClass {
 	void (*select_part) (BalsaMessage * message);
 };
 
-GtkType balsa_message_get_type(void);
+GType balsa_message_get_type(void);
 GtkWidget *balsa_message_new(void);
 void balsa_message_set_close(BalsaMessage * bmessage,
 			     gboolean close_with_msg);
 
 gboolean balsa_message_set(BalsaMessage * bmessage,
-			   LibBalsaMessage * message);
+			   LibBalsaMailbox * mailbox, guint msgno);
 
 void balsa_message_next_part(BalsaMessage * bmessage);
 gboolean balsa_message_has_next_part(BalsaMessage * bmessage);
 void balsa_message_previous_part(BalsaMessage * bmessage);
 gboolean balsa_message_has_previous_part(BalsaMessage * bmessage);
 void balsa_message_save_current_part(BalsaMessage * bmessage);
+void balsa_message_copy_part(const gchar *url, LibBalsaMessageBody *part);
 
 void balsa_message_set_displayed_headers(BalsaMessage * bmessage,
 					     ShownHeaders sh);
@@ -109,12 +127,13 @@ gboolean balsa_message_can_select(BalsaMessage * bmessage);
 gboolean balsa_message_grab_focus(BalsaMessage * bmessage);
 gchar * balsa_message_sender_to_gchar(InternetAddressList * list, gint which);
 GtkWidget *balsa_message_current_part_widget(BalsaMessage * bmessage);
+GtkWindow *balsa_get_parent_window(GtkWidget *widget);
 
-#ifdef HAVE_GTKHTML
+#ifdef HAVE_HTML_WIDGET
 #define BALSA_MESSAGE_ZOOM_KEY "balsa-message-zoom"
 gboolean balsa_message_can_zoom(BalsaMessage * bm);
 void balsa_message_zoom(BalsaMessage * bm, gint in_out);
-#endif				/* HAVE_GTKHTML */
+#endif				/* HAVE_HTML_WIDGET */
 
 #ifdef HAVE_GPGME
 void balsa_message_perform_crypto(LibBalsaMessage * message,
@@ -123,6 +142,8 @@ void balsa_message_perform_crypto(LibBalsaMessage * message,
 				  guint max_ref);
 #endif
 
+void balsa_message_find_in_message (BalsaMessage * bm);
+
 #ifdef __cplusplus
 }
 #endif				/* __cplusplus */
