@@ -23,7 +23,9 @@
  * Callbacks for the filter run dialog
  */
 
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
 
 #include <string.h>
 
@@ -35,12 +37,6 @@
 
 #include <glib/gi18n.h>	/* Must come after balsa-app.h. */
 
-#if !GTK_CHECK_VERSION(2, 14, 0)
-#ifdef HAVE_GNOME
-#include <gnome.h>
-#endif
-#endif                          /* GTK_CHECK_VERSION(2, 14, 0) */
-
 /* Global vars */
 
 extern GList * fr_dialogs_opened;
@@ -165,9 +161,7 @@ void fr_dialog_response(GtkWidget * widget, gint response,
 			gpointer throwaway)
 {
     BalsaFilterRunDialog * p;
-#if GTK_CHECK_VERSION(2, 14, 0) || HAVE_GNOME
-    GError *err;
-#endif
+    GError *err = NULL;
 
     p=BALSA_FILTER_RUN_DIALOG(widget);
     switch (response) {
@@ -182,14 +176,8 @@ void fr_dialog_response(GtkWidget * widget, gint response,
 	
 	break;
     case GTK_RESPONSE_HELP:     /* Help button */
-#if GTK_CHECK_VERSION(2, 14, 0) || HAVE_GNOME
-	err = NULL;
-#if GTK_CHECK_VERSION(2, 14, 0)
         gtk_show_uri(NULL, "ghelp:balsa?win-run-filters",
                      gtk_get_current_event_time(), &err);
-#else                           /* GTK_CHECK_VERSION(2, 14, 0) */
-	gnome_help_display("balsa", "win-run-filters", &err);
-#endif                          /* GTK_CHECK_VERSION(2, 14, 0) */
 	if (err) {
 	    balsa_information_parented(GTK_WINDOW(widget),
 		    LIBBALSA_INFORMATION_WARNING,
@@ -197,7 +185,6 @@ void fr_dialog_response(GtkWidget * widget, gint response,
 		    err->message);
 	    g_error_free(err);
 	}
-#endif
 	return;
 
     default:
@@ -221,8 +208,10 @@ fr_apply_selected_pressed_func(GtkTreeModel * model, GtkTreePath * path,
 
     gtk_tree_model_get(model, iter, DATA_COLUMN, &fil, -1);
     /* Check for move to self: */
-    if (fil->action == FILTER_RUN || fil->action == FILTER_TRASH ||
-        strcmp(fil->action_string, p->mbox->url) != 0)
+    if (fil->action == FILTER_RUN
+        || fil->action == FILTER_TRASH
+        || (fil->action == FILTER_COLOR && fil->action_string[0])
+        || strcmp(fil->action_string, p->mbox->url) != 0)
         p->filters = g_slist_append(p->filters, fil);
 }
 
@@ -279,8 +268,10 @@ fr_add_pressed_func(GtkTreeModel * model, GtkTreePath * path,
     LibBalsaFilter *fil;
 
     gtk_tree_model_get(model, iter, DATA_COLUMN, &fil, -1);
-    if (fil->action == FILTER_RUN || fil->action == FILTER_TRASH ||
-        strcmp(fil->action_string, p->mbox->url) != 0) {
+    if (fil->action == FILTER_RUN
+        || fil->action == FILTER_TRASH
+        || (fil->action == FILTER_COLOR && fil->action_string[0])
+        || strcmp(fil->action_string, p->mbox->url) != 0) {
         /* Ok we can add the filter to this mailbox, there is no recursion problem */
         LibBalsaMailboxFilter *mf = g_new(LibBalsaMailboxFilter, 1);
         GtkTreeModel *sel_model =
