@@ -738,12 +738,19 @@ folder, parent);
    representing a sub-folder.
    If mn is NULL, setup it with default values for folder creation.
 */
+static void
+set_ok_sensitive(GtkDialog * dialog)
+{
+    gtk_dialog_set_response_sensitive(dialog, GTK_RESPONSE_OK, TRUE);
+}
+
 void
 folder_conf_imap_sub_node(BalsaMailboxNode * mn)
 {
-    GtkWidget *frame, *table, *subtable, *button, *label;
+    GtkWidget *content, *table, *button, *label, *hbox;
     SubfolderDialogData *sdd;
     static SubfolderDialogData *sdd_new = NULL;
+    guint row;
 
     /* Allow only one dialog per mailbox node, and one with mn == NULL
      * for creating a new subfolder. */
@@ -780,7 +787,7 @@ folder_conf_imap_sub_node(BalsaMailboxNode * mn)
                     GTK_WINDOW(balsa_app.main_window),
                     GTK_DIALOG_DESTROY_WITH_PARENT, /* must NOT be modal */
                     mn ? _("_Update") : _("_Create"), GTK_RESPONSE_OK,
-                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
+                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                     GTK_STOCK_HELP,   GTK_RESPONSE_HELP,
                     NULL));
 #if HAVE_MACOSX_DESKTOP
@@ -797,59 +804,177 @@ folder_conf_imap_sub_node(BalsaMailboxNode * mn)
         g_object_set_data_full(G_OBJECT(sdd->mbnode),
                                BALSA_FOLDER_CONF_IMAP_KEY, sdd, 
                                (GDestroyNotify) folder_conf_destroy_cdd);
-        } else {
+    } else {
         sdd_new = sdd;
         g_object_add_weak_pointer(G_OBJECT(sdd->dialog),
                                   (gpointer) &sdd_new);
     }
 
-    frame = gtk_frame_new(mn ? _("Rename or move subfolder") :
-			       _("Create subfolder"));
-    gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(sdd->dialog)),
-                       frame, TRUE, TRUE, 0);
-    table = libbalsa_create_table(3, 3);
+    table = libbalsa_create_table(3, 2);
+    gtk_table_set_row_spacings(GTK_TABLE(table), 6);
+    gtk_table_set_col_spacings(GTK_TABLE(table), 12);
     gtk_container_set_border_width(GTK_CONTAINER(table), 12);
-    gtk_container_add(GTK_CONTAINER(frame), table);
+    if (mn)
+        content = table;
+    else {
+        content = gtk_frame_new(_("Create subfolder"));
+        gtk_container_add(GTK_CONTAINER(content), table);
+    }
+    gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(sdd->dialog)),
+                       content, TRUE, TRUE, 0);
  
+    row = 0;
     /* INPUT FIELD CREATION */
-    label= libbalsa_create_label(_("_Folder name:"), table, 0);
-    sdd->folder_name = libbalsa_create_entry(table,
-                                   G_CALLBACK(validate_sub_folder),
-				   sdd, 0, sdd->old_folder, label);
+    label= libbalsa_create_label(_("_Folder name:"), table, row);
+    sdd->folder_name =
+        libbalsa_create_entry(table, G_CALLBACK(validate_sub_folder),
+                              sdd, row, sdd->old_folder, label);
 
-    subtable = libbalsa_create_table(1, 3);
-    label = libbalsa_create_label(_("Host:"), table, 1);
+    ++row;
+    label = libbalsa_create_label(_("Host:"), table, row);
     sdd->host_label = 
         gtk_label_new(sdd->mbnode && sdd->mbnode->server
                       ? sdd->mbnode->server->host : "");
-    gtk_table_attach(GTK_TABLE(subtable), sdd->host_label, 1, 2, 0, 1,
-		     GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 5);
+    gtk_misc_set_alignment(GTK_MISC(sdd->host_label), 0.0, 0.5);
+    gtk_table_attach(GTK_TABLE(table), sdd->host_label, 1, 2, row, row + 1,
+		     GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+
+    ++row;
+    label = libbalsa_create_label(_("Subfolder of:"), table, row);
+    sdd->parent_folder = gtk_entry_new();
+    gtk_editable_set_editable(GTK_EDITABLE(sdd->parent_folder), FALSE);
+    gtk_entry_set_text(GTK_ENTRY(sdd->parent_folder), sdd->old_parent);
+
     button = gtk_button_new_with_mnemonic(_("_Browse..."));
     g_signal_connect(G_OBJECT(button), "clicked",
 		     G_CALLBACK(browse_button_cb), (gpointer) sdd);
-    gtk_table_attach(GTK_TABLE(subtable), button, 2, 3, 0, 1,
-	GTK_FILL, GTK_FILL, 5, 5);
-    gtk_table_attach(GTK_TABLE(table), subtable, 1, 2, 1, 2,
-	GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 5);
 
-    label = libbalsa_create_label(_("_Subfolder of:"), table, 2);
-    sdd->parent_folder = libbalsa_create_entry(table,
-                                     G_CALLBACK(validate_sub_folder),
-				     sdd, 2, sdd->old_parent, label);
+    hbox = gtk_hbox_new(FALSE, 12);
+    gtk_box_pack_start(GTK_BOX(hbox), sdd->parent_folder, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+    gtk_table_attach(GTK_TABLE(table), hbox, 1, 2, row, row + 1,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
+    if (!mn)
+        validate_sub_folder(NULL, sdd);
+    else {
+        static const char *std_acls[] = {
+            "lrs", N_("read-only"),
+            "lrswipkxte", N_("read-write"),
+            "lrswipkxtea", N_("admin"),
+            "lrsp", N_("post"),
+            "lrsip", N_("append"),
+            "lrxte", N_("delete"),
+            NULL, N_("special") };
+        GString *rights_str;
+        gchar * rights;
+        gchar * quotas;
+
+        ++row;
+        label = libbalsa_create_label(_("Permissions:"), table, row);
+
+        /* mailbox closed: no detailed permissions available */
+        if (!libbalsa_mailbox_imap_is_connected(LIBBALSA_MAILBOX_IMAP(mn->mailbox))) {
+            rights_str = g_string_new(std_acls[mn->mailbox->readonly ? 1 : 3]);
+            rights_str =
+                g_string_append(rights_str,
+                                _("\ndetailed permissions are available only for open folders"));
+        } else {
+            rights = libbalsa_imap_get_rights(LIBBALSA_MAILBOX_IMAP(mn->mailbox));
+            if (!rights) {
+                rights_str = g_string_new(std_acls[mn->mailbox->readonly ? 1 : 3]);
+                rights_str =
+                    g_string_append(rights_str,
+                                    _("\nthe server does not support ACL's"));
+            } else {
+                gint n;
+                gchar **acls;
+
+                /* my rights */
+                for (n = 0;
+                     std_acls[n] && strcmp(std_acls[n], rights);
+                     n += 2);
+                rights_str = g_string_new(_("mine: "));
+                if (std_acls[n])
+                    rights_str = g_string_append(rights_str, std_acls[n + 1]);
+                else
+                    g_string_append_printf(rights_str, "%s (%s)",
+                                           std_acls[n + 1], rights);
+
+                /* acl's - only available if I have admin privileges */
+                if ((acls =
+                     libbalsa_imap_get_acls(LIBBALSA_MAILBOX_IMAP(mn->mailbox)))) {
+                    int uid;
+
+                    for (uid = 0; acls[uid]; uid += 2) {
+                        for (n = 0;
+                             std_acls[n] && strcmp(std_acls[n], acls[uid + 1]);
+                             n += 2);
+                        if (std_acls[n])
+                            g_string_append_printf(rights_str,
+                                                   "\nuid '%s': %s",
+                                                   acls[uid], std_acls[n + 1]);
+                        else
+                            g_string_append_printf(rights_str,
+                                                   "\nuid '%s': %s (%s)",
+                                                   acls[uid], std_acls[n + 1],
+                                                   acls[uid + 1]);
+                    }
+                    g_strfreev(acls);
+                }
+                g_free(rights);
+            }
+        }
+        rights = g_string_free(rights_str, FALSE);
+        label = gtk_label_new(rights);
+        gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+        gtk_table_attach(GTK_TABLE(table), label, 1, 2, row, row + 1,
+                         GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+        g_free(rights);
+
+        ++row;
+        label = libbalsa_create_label(_("Quota:"), table, row);
+
+        /* mailbox closed: no quota available */
+        if (!libbalsa_mailbox_imap_is_connected(LIBBALSA_MAILBOX_IMAP(mn->mailbox)))
+            quotas = g_strdup(_("quota information available only for open folders"));
+        else {
+            gulong max, used;
+
+            if (!libbalsa_imap_get_quota(LIBBALSA_MAILBOX_IMAP(mn->mailbox), &max, &used))
+                quotas = g_strdup(_("the server does not support quotas"));
+            else if (max == 0 && used == 0)
+                quotas = g_strdup(_("no limits"));
+            else {
+                gchar *use_str = libbalsa_size_to_gchar(used * G_GUINT64_CONSTANT(1024));
+                gchar *max_str = libbalsa_size_to_gchar(max * G_GUINT64_CONSTANT(1024));
+
+                quotas = g_strdup_printf(_("%s of %s (%.1f%%) used"), use_str, max_str,
+                                         100.0 * (float) used / (float) max);
+                g_free(use_str);
+                g_free(max_str);
+            }
+        }
+        label = gtk_label_new(quotas);
+        gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+        gtk_table_attach(GTK_TABLE(table), label, 1, 2, row, row + 1,
+                         GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+        g_free(quotas);
 
-    if (mn)
         sdd->mcv = mailbox_conf_view_new(mn->mailbox,
                                          GTK_WINDOW(sdd->dialog),
-                                         table, 3);
+                                         table, 5,
+                                         G_CALLBACK(set_ok_sensitive));
+    }
 
     gtk_widget_show_all(GTK_WIDGET(sdd->dialog));
 
-    validate_sub_folder(NULL, sdd);
     gtk_widget_grab_focus(sdd->folder_name);
 
     g_signal_connect(G_OBJECT(sdd->dialog), "response",
                      G_CALLBACK(folder_conf_response), sdd);
+    gtk_dialog_set_response_sensitive(GTK_DIALOG(sdd->dialog),
+                                      GTK_RESPONSE_OK, FALSE);
     gtk_widget_show_all(GTK_WIDGET(sdd->dialog));
 }
 
