@@ -24,15 +24,19 @@
  * received from libbalsa
  */
 
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
+#include "information-dialog.h"
 
-#include <gnome.h>
 #include <string.h>
 
-#include "libbalsa.h"
-#include "i18n.h"
+#include <glib/gi18n.h>
 #include "balsa-app.h"
-#include "information-dialog.h"
+
+#if HAVE_MACOSX_DESKTOP
+#  include "macosx-helpers.h"
+#endif
 
 static void balsa_information_bar(GtkWindow *parent,
                                   LibBalsaInformationType type,
@@ -180,6 +184,9 @@ balsa_information_dialog(GtkWindow *parent, LibBalsaInformationType type,
                                GTK_DIALOG_DESTROY_WITH_PARENT,
                                message_type, GTK_BUTTONS_CLOSE,
                                "%s", msg);
+#if HAVE_MACOSX_DESKTOP
+    libbalsa_macosx_menu_for_parent(messagebox, GTK_WINDOW(parent));
+#endif
 
     gtk_dialog_run(GTK_DIALOG(messagebox));
     gtk_widget_destroy(messagebox);
@@ -228,6 +235,9 @@ balsa_information_list(GtkWindow *parent, LibBalsaInformationType type,
                                         GTK_STOCK_CLEAR, GTK_RESPONSE_APPLY,
                                         GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
                                         NULL);
+#if HAVE_MACOSX_DESKTOP
+	libbalsa_macosx_menu_for_parent(information_dialog, parent);
+#endif
 	/* Default is to close */
 	gtk_dialog_set_default_response(GTK_DIALOG(information_dialog), 
                                         GTK_RESPONSE_CLOSE);
@@ -247,8 +257,10 @@ balsa_information_list(GtkWindow *parent, LibBalsaInformationType type,
 				       (scrolled_window),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(information_dialog)->vbox),
-			   scrolled_window, TRUE, TRUE, 1);
+        gtk_box_pack_start(GTK_BOX
+                           (gtk_dialog_get_content_area
+                            (GTK_DIALOG(information_dialog))),
+                           scrolled_window, TRUE, TRUE, 1);
 	gtk_container_set_border_width(GTK_CONTAINER(scrolled_window), 6);
 	gtk_widget_show(scrolled_window);
 
@@ -273,10 +285,18 @@ balsa_information_list(GtkWindow *parent, LibBalsaInformationType type,
                                  gtk_text_buffer_get_insert(buffer),
                                  0, FALSE, 0, 0);
 
-    if (balsa_app.appbar) {
-        gchar *line = g_strdup(msg);
+    if (balsa_app.main_window) {
+        gchar *line;
+        GtkStatusbar *statusbar;
+        guint context_id;
+
+        statusbar = GTK_STATUSBAR(balsa_app.main_window->statusbar);
+        context_id = gtk_statusbar_get_context_id(statusbar, "Information list");
+        gtk_statusbar_pop(statusbar, context_id);
+
+        line = g_strdup(msg);
         g_strdelimit(line, "\r\n", ' ');
-	gnome_appbar_set_status(balsa_app.appbar, line);
+        gtk_statusbar_push(statusbar, context_id, line);
         g_free(line);
     }
 }
@@ -287,8 +307,14 @@ status_bar_refresh(gpointer data)
 {
     gdk_threads_enter();
 
-    if (balsa_app.appbar)
-        gnome_appbar_pop(balsa_app.appbar);
+    if (balsa_app.main_window) {
+        GtkStatusbar *statusbar;
+        guint context_id;
+
+        statusbar = GTK_STATUSBAR(balsa_app.main_window->statusbar);
+        context_id = gtk_statusbar_get_context_id(statusbar, "Information bar");
+        gtk_statusbar_pop(statusbar, context_id);
+    }
 
     bar_timeout_id = 0;
 
@@ -302,22 +328,27 @@ balsa_information_bar(GtkWindow *parent, LibBalsaInformationType type,
                       const char *msg)
 {
     gchar *line;
+    GtkStatusbar *statusbar;
+    guint context_id;
 
-    if (!balsa_app.appbar)
+    if (!balsa_app.main_window)
         return;
 
+    statusbar = GTK_STATUSBAR(balsa_app.main_window->statusbar);
+    context_id = gtk_statusbar_get_context_id(statusbar, "Information bar");
+
     /* First clear any current message. */
     if (bar_timeout_id) {
-        gnome_appbar_pop(balsa_app.appbar);
+        gtk_statusbar_pop(statusbar, context_id);
         g_source_remove(bar_timeout_id);
     }
 
     line = g_strdup(msg);
     g_strdelimit(line, "\r\n", ' ');
-    gnome_appbar_push(balsa_app.appbar, line);
+    gtk_statusbar_push(statusbar, context_id, line);
     g_free(line);
 
-    bar_timeout_id = g_timeout_add(4000, status_bar_refresh, NULL);
+    bar_timeout_id = g_timeout_add_seconds(4, status_bar_refresh, NULL);
 }
 
 static void 
