@@ -43,7 +43,8 @@ void mailbox_conf_edit_cb(GtkWidget * widget, gpointer data);
 /* Helpers for dialogs. */
 BalsaMailboxConfView *mailbox_conf_view_new(LibBalsaMailbox * mailbox,
                                             GtkWindow * window,
-                                            GtkWidget * table, gint row);
+                                            GtkWidget * table, gint row,
+                                            GCallback callback);
 void mailbox_conf_view_check(BalsaMailboxConfView * mcc,
                              LibBalsaMailbox * mailbox);
 
