@@ -19,7 +19,10 @@
  * 02111-1307, USA.
  */
 
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
+#include "mailbox-node.h"
 
 #include <unistd.h>
 #include <string.h>
@@ -28,7 +31,6 @@
 #include "folder-scanners.h"
 #include "folder-conf.h"
 #include "mailbox-conf.h"
-#include "mailbox-node.h"
 #include "save-restore.h"
 #include "filter.h"
 #include "imap-server.h"
@@ -341,7 +343,7 @@ check_local_path(const gchar * path, guint depth)
         return TRUE;
 
     len = strlen(balsa_app.local_mail_directory);
-    if (!strncmp(path, balsa_app.local_mail_directory, len)
+    if (libbalsa_path_is_below_dir(path, balsa_app.local_mail_directory)
 	&& !strchr(&path[++len], G_DIR_SEPARATOR))
 	/* Top level folder. */
 	return TRUE;
@@ -361,10 +363,13 @@ check_local_path(const gchar * path, guint depth)
     return cpi.must_scan;
 }
 
-static void
+static gboolean
 mark_local_path(BalsaMailboxNode *mbnode)
 {
+    if (mbnode->scanned)
+        return FALSE;
     mbnode->scanned = TRUE;
+    return TRUE;
 }
 
 /** Read local directory in search for mailboxes. Never does any
@@ -395,7 +400,7 @@ load_mailbox_view(BalsaMailboxNode * mbnode)
     if (libbalsa_mailbox_get_frozen(mailbox)
 	&& libbalsa_mailbox_get_open(mailbox))
 	/* We are rescanning. */
-	balsa_window_open_mbnode(balsa_app.main_window, mbnode);
+	balsa_window_open_mbnode(balsa_app.main_window, mbnode, TRUE);
     libbalsa_mailbox_set_frozen(mailbox, FALSE);
 }
 
@@ -709,6 +714,14 @@ balsa_mailbox_node_save_config(BalsaMailboxNode* mn, const gchar* group)
 /* ---------------------------------------------------------------------
  * Rescanning.
  * --------------------------------------------------------------------- */
+static BalsaMailboxNode *
+find_dir(const gchar * dir)
+{
+    if (strcmp(dir, balsa_app.local_mail_directory) == 0)
+        return g_object_ref(balsa_app.root_node);
+    return balsa_find_dir(NULL, dir);
+}
+
 void
 balsa_mailbox_local_append(LibBalsaMailbox* mbx)
 {
@@ -720,7 +733,7 @@ balsa_mailbox_local_append(LibBalsaMailbox* mbx)
 
     for(dir = g_strdup(libbalsa_mailbox_local_get_path(mbx));
         strlen(dir)>1 /* i.e dir != "/" */ &&
-            !(parent = balsa_find_dir(NULL, dir));
+            !(parent = find_dir(dir));
         ) {
         gchar* tmp =  g_path_get_dirname(dir);
         g_free(dir);
@@ -749,9 +762,15 @@ balsa_mailbox_node_rescan(BalsaMailboxNode * mn)
     if (!balsa_app.mblist_tree_store)
         return;
 
-    balsa_mailbox_node_clear_children_cache(mn);
-    balsa_remove_children_mailbox_nodes(mn);
-    balsa_mailbox_node_append_subtree(mn ? mn : balsa_app.root_node);
+    if (mn) {
+        balsa_mailbox_node_clear_children_cache(mn);
+        balsa_remove_children_mailbox_nodes(mn);
+    } else {
+        balsa_remove_children_mailbox_nodes(mn);
+        mn = balsa_app.root_node;
+    }
+    mn->scanned = FALSE;
+    balsa_mailbox_node_append_subtree(mn);
 }
 
 void
@@ -894,7 +913,7 @@ bmbn_scan_children_idle(BalsaMailboxNode ** mbnode)
  * Context menu, helpers, and callbacks.
  * --------------------------------------------------------------------- */
 static void
-add_menu_entry(GtkWidget * menu, const gchar * label, GtkSignalFunc cb,
+add_menu_entry(GtkWidget * menu, const gchar * label, GCallback cb,
 	       BalsaMailboxNode * mbnode)
 {
     GtkWidget *menuitem;
@@ -1025,18 +1044,18 @@ balsa_mailbox_node_get_context_menu(BalsaMailboxNode * mbnode)
 
     submenu = gtk_menu_new();
     add_menu_entry(submenu, _("Local _mbox mailbox..."),  
-		   GTK_SIGNAL_FUNC(mailbox_conf_add_mbox_cb), NULL);
+		   G_CALLBACK(mailbox_conf_add_mbox_cb), NULL);
     add_menu_entry(submenu, _("Local Mail_dir mailbox..."), 
-		   GTK_SIGNAL_FUNC(mailbox_conf_add_maildir_cb), NULL);
+		   G_CALLBACK(mailbox_conf_add_maildir_cb), NULL);
     add_menu_entry(submenu, _("Local M_H mailbox..."),
-		   GTK_SIGNAL_FUNC(mailbox_conf_add_mh_cb), NULL);
+		   G_CALLBACK(mailbox_conf_add_mh_cb), NULL);
     add_menu_entry(submenu, _("Remote _IMAP mailbox..."), 
-		   GTK_SIGNAL_FUNC(mailbox_conf_add_imap_cb), NULL);
+		   G_CALLBACK(mailbox_conf_add_imap_cb), NULL);
     add_menu_entry(submenu, NULL, NULL, mbnode);
     add_menu_entry(submenu, _("Remote IMAP _folder..."), 
-		   GTK_SIGNAL_FUNC(folder_conf_add_imap_cb), NULL);
+		   G_CALLBACK(folder_conf_add_imap_cb), NULL);
     add_menu_entry(submenu, _("Remote IMAP _subfolder..."), 
-		   GTK_SIGNAL_FUNC(folder_conf_add_imap_sub_cb), NULL);
+		   G_CALLBACK(folder_conf_add_imap_sub_cb), NULL);
     gtk_widget_show(submenu);
     
     menuitem = gtk_menu_item_new_with_mnemonic(_("_New"));
@@ -1046,7 +1065,7 @@ balsa_mailbox_node_get_context_menu(BalsaMailboxNode * mbnode)
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
     
     if(mbnode == NULL) {/* clicked on the empty space */
-        add_menu_entry(menu, _("_Rescan"), GTK_SIGNAL_FUNC(mb_rescan_cb), 
+        add_menu_entry(menu, _("_Rescan"), G_CALLBACK(mb_rescan_cb), 
                        NULL);
 	return menu;
     }
@@ -1063,7 +1082,7 @@ balsa_mailbox_node_get_context_menu(BalsaMailboxNode * mbnode)
 		                     balsa_mailbox_node_signals
 				     [APPEND_SUBTREE], 0, FALSE))
 	add_menu_entry(menu, _("_Rescan"),
-		       GTK_SIGNAL_FUNC(mb_rescan_cb), mbnode);
+		       G_CALLBACK(mb_rescan_cb), mbnode);
 
     if (mbnode->config_prefix)
 	add_menu_entry(menu, _("_Delete"), G_CALLBACK(mb_del_cb),  mbnode);
@@ -1087,29 +1106,29 @@ balsa_mailbox_node_get_context_menu(BalsaMailboxNode * mbnode)
     if(LIBBALSA_IS_MAILBOX_IMAP(mailbox)) {
         add_menu_entry(menu, NULL, NULL, NULL);
         add_menu_entry(menu, _("_Subscribe"),   
-                       GTK_SIGNAL_FUNC(mb_subscribe_cb),   mbnode);
+                       G_CALLBACK(mb_subscribe_cb),   mbnode);
         add_menu_entry(menu, _("_Unsubscribe"), 
-                       GTK_SIGNAL_FUNC(mb_unsubscribe_cb), mbnode);
+                       G_CALLBACK(mb_unsubscribe_cb), mbnode);
     }
 
     if (!special) {
         add_menu_entry(menu, NULL, NULL, NULL);
         add_menu_entry(menu, _("Mark as _Inbox"),    
-                       GTK_SIGNAL_FUNC(mb_inbox_cb),    mbnode);
+                       G_CALLBACK(mb_inbox_cb),    mbnode);
         add_menu_entry(menu, _("_Mark as Sentbox"), 
-                       GTK_SIGNAL_FUNC(mb_sentbox_cb),  mbnode);
+                       G_CALLBACK(mb_sentbox_cb),  mbnode);
         add_menu_entry(menu, _("Mark as _Trash"),    
-                       GTK_SIGNAL_FUNC(mb_trash_cb),    mbnode);
+                       G_CALLBACK(mb_trash_cb),    mbnode);
         add_menu_entry(menu, _("Mark as D_raftbox"),
-                       GTK_SIGNAL_FUNC(mb_draftbox_cb), mbnode);
+                       G_CALLBACK(mb_draftbox_cb), mbnode);
     } else if (mailbox == balsa_app.trash)
         add_menu_entry(menu, _("_Empty trash"),    
-                       GTK_SIGNAL_FUNC(mb_empty_trash_cb), mbnode);
+                       G_CALLBACK(mb_empty_trash_cb), mbnode);
 
     /* FIXME : No test on mailbox type is made yet, should we ? */
     add_menu_entry(menu, NULL, NULL, NULL);
     add_menu_entry(menu, _("_Edit/Apply filters"), 
-                   GTK_SIGNAL_FUNC(mb_filter_cb), mbnode);
+                   G_CALLBACK(mb_filter_cb), mbnode);
 
     return menu;
 }
@@ -1212,7 +1231,9 @@ add_local_mailbox(BalsaMailboxNode *root, const gchar * name,
 	    g_print(_("Local mailbox %s loaded as: %s\n"),
 		    mailbox->name,
 		    g_type_name(G_OBJECT_TYPE(mailbox)));
-	if (balsa_app.check_mail_upon_startup) {
+        if (balsa_app.check_mail_upon_startup
+            && libbalsa_mailbox_get_subscribe(mailbox) !=
+            LB_MAILBOX_SUBSCRIBE_NO) {
             g_object_ref(mailbox);
             g_idle_add((GSourceFunc) mailbox_check_idle, mailbox);
         }
