@@ -24,6 +24,9 @@
 #endif                          /* HAVE_CONFIG_H */
 
 #if HAVE_UNIQUE
+#ifndef G_CONST_RETURN
+#  define G_CONST_RETURN const
+#endif
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <unique/unique.h>
@@ -78,8 +81,8 @@
 #endif                          /* HAVE_UNIQUE */
 
 #ifdef HAVE_GPGME
-#include <string.h>
-#include <gpgme.h>
+#include "libbalsa-gpgme.h"
+#include "libbalsa-gpgme-cb.h"
 #endif
 
 #ifdef BALSA_USE_THREADS
@@ -943,26 +946,6 @@ balsa_progress_set_activity(gboolean set, const gchar * text)
     gdk_threads_leave();
 }
 
-#if defined(ENABLE_NLS) && defined(HAVE_GPGME)
-static const gchar *
-get_utf8_locale(int category)
-{
-    gchar * locale;
-    static gchar localebuf[64];  /* should be large enough */
-    gchar * dot;
-
-    if (!(locale = setlocale(category, NULL)))
-	return NULL;
-    strncpy(localebuf, locale, 57);
-    localebuf[57] = '\0';
-    dot = strchr(localebuf, '.');
-    if (!dot)
-	dot = localebuf + strlen(localebuf);
-    strcpy(dot, ".UTF-8");
-    return localebuf;
-}
-#endif
-
 /* -------------------------- main --------------------------------- */
 int
 main(int argc, char *argv[])
@@ -1035,27 +1018,9 @@ main(int argc, char *argv[])
 #endif                          /* HAVE_UNIQUE */
 
 #ifdef HAVE_GPGME
-    /* initialise the gpgme library */
-    g_message("init gpgme version %s", gpgme_check_version(NULL));
-#ifdef HAVE_GPG
-    /* configure the GnuPG engine if a specific gpg path has been detected*/
-    gpgme_set_engine_info(GPGME_PROTOCOL_OpenPGP, GPG_PATH, NULL);
-#endif
-#ifdef ENABLE_NLS
-    gpgme_set_locale(NULL, LC_CTYPE, get_utf8_locale(LC_CTYPE));
-    gpgme_set_locale(NULL, LC_MESSAGES, get_utf8_locale(LC_MESSAGES));
-#endif /* ENABLE_NLS */
-    { /* scope */
-	gpgme_engine_info_t e;
-
-	if (gpgme_get_engine_info(&e) == GPG_ERR_NO_ERROR)
-	    while (e) {
-		g_message("protocol %s: engine %s (home %s, version %s)",
-			  gpgme_get_protocol_name(e->protocol),
-			  e->file_name, e->home_dir, e->version);
-		e = e->next;
-	    }
-    }
+    /* initialise the gpgme library and set the callback funcs */
+    libbalsa_gpgme_init(lb_gpgme_passphrase, lb_gpgme_select_key,
+			lb_gpgme_accept_low_trust_key);
 #endif
 
 #ifdef GTKHTML_HAVE_GCONF
@@ -1137,13 +1102,9 @@ main(int argc, char *argv[])
 
 #ifdef HAVE_GPGME
     balsa_app.has_openpgp = 
-        libbalsa_check_crypto_engine(GPGME_PROTOCOL_OpenPGP);
-#ifdef HAVE_SMIME
+        libbalsa_gpgme_check_crypto_engine(GPGME_PROTOCOL_OpenPGP);
     balsa_app.has_smime =
-       libbalsa_check_crypto_engine(GPGME_PROTOCOL_CMS);
-#else
-    balsa_app.has_smime = FALSE;
-#endif /* HAVE_SMIME */
+	libbalsa_gpgme_check_crypto_engine(GPGME_PROTOCOL_CMS);
 #endif /* HAVE_GPGME */
     
     if (opt_compose_email || opt_attach_list) {
