@@ -22,23 +22,35 @@
 #ifndef __BALSA_QUOTECOLOR_H__
 #define __BALSA_QUOTECOLOR_H__
 
+#ifndef BALSA_VERSION
+# error "Include config.h before this file."
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif				/* __cplusplus */
 
+#include <gtk/gtk.h>
+
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#include "config.h"
-#ifdef HAVE_PCRE
-#  include <pcreposix.h>
-#else
-#  include <sys/types.h>
-#  include <regex.h>
-#endif
+
+#if !USE_GREGEX
+#  ifdef HAVE_PCRE
+#    include <pcreposix.h>
+#  else
+#    include <sys/types.h>
+#    include <regex.h>
+#  endif
+#endif                          /* USE_GREGEX */
 
     extern void make_gradient(GdkColor colors[], gint, gint);
+#if USE_GREGEX
+    extern guint is_a_quote(const gchar *, GRegex * rex);
+#else                           /* USE_GREGEX */
     extern guint is_a_quote(const gchar *, regex_t * rex);
+#endif                          /* USE_GREGEX */
     extern void allocate_quote_colors(GtkWidget *, GdkColor color[], gint, gint);
 
 
