@@ -19,24 +19,35 @@
  * 02111-1307, USA.
  */
 
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
+#include "toolbar-prefs.h"
 
 #include <string.h>
-#include <gnome.h>
-#include "i18n.h"
+#include <glib/gi18n.h>
 
 #include "balsa-app.h"
 #include "balsa-icons.h"
 #include "main-window.h"
 #include "message-window.h"
 #include "sendmsg-window.h"
-#include "toolbar-prefs.h"
+#include "toolbar-factory.h"
+
+#if HAVE_MACOSX_DESKTOP
+#  include "macosx-helpers.h"
+#endif
 
 #ifndef MAX
 #define MAX(a, b) ((a) > (b) ? (a) : (b))
 #endif
 
+#ifdef HAVE_GNOME
 #define OLD_BALSA_COMPATIBILITY_TRANSLATION
+#endif
+#ifdef OLD_BALSA_COMPATIBILITY_TRANSLATION
+#include <gnome.h> /* for GNOME_STOCK_* pixmaps */
+#endif
 
 /* Enumeration for GtkTreeModel columns. */
 enum {
@@ -60,7 +71,6 @@ struct ToolbarPage_ {
     GtkWidget *back_button;
     GtkWidget *forward_button;
     GtkWidget *standard_button;
-    gboolean needs_refresh;
 };
 
 /* Callbacks. */
@@ -85,7 +95,8 @@ static void current_row_activated_cb(GtkTreeView * treeview,
                                      ToolbarPage * page);
 
 /* Helpers. */
-static GtkWidget *create_toolbar_page(BalsaToolbarModel * model);
+static GtkWidget *create_toolbar_page(BalsaToolbarModel * model,
+                                      GtkUIManager * ui_manager);
 static GtkWidget *tp_list_new(void);
 static gboolean tp_list_iter_is_first(GtkWidget * list, GtkTreeIter * iter);
 static gboolean tp_list_iter_is_last(GtkWidget * list, GtkTreeIter * iter);
@@ -111,11 +122,15 @@ customize_dialog_cb(GtkWidget * widget, gpointer data)
     GtkWidget *option_frame;
     GtkWidget *option_box;
     GtkWidget *wrap_button;
-    GnomeApp *active_window = GNOME_APP(data);
+    GtkWidget *active_window = data;
+    BalsaToolbarModel *model;
+    BalsaToolbarType   type;
+    GtkUIManager * ui_manager;
+    GtkWidget *content_area;
 
     /* There can only be one */
     if (customize_widget) {
-        gdk_window_raise(customize_widget->window);
+        gtk_window_present(GTK_WINDOW(customize_widget));
         return;
     }
 
@@ -126,35 +141,49 @@ customize_dialog_cb(GtkWidget * widget, gpointer data)
                                     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
                                     GTK_STOCK_HELP,  GTK_RESPONSE_HELP,
                                     NULL);
+#if HAVE_MACOSX_DESKTOP
+    libbalsa_macosx_menu_for_parent(customize_widget, GTK_WINDOW(active_window));
+#endif
     g_object_add_weak_pointer(G_OBJECT(customize_widget),
                               (gpointer) & customize_widget);
     g_signal_connect(G_OBJECT(customize_widget), "response",
                      G_CALLBACK(tp_dialog_response_cb), NULL);
 
     notebook = gtk_notebook_new();
-    gtk_container_add(GTK_CONTAINER(GTK_DIALOG(customize_widget)->vbox),
-                      notebook);
+    content_area =
+        gtk_dialog_get_content_area(GTK_DIALOG(customize_widget));
+    gtk_container_add(GTK_CONTAINER(content_area), notebook);
 
     gtk_window_set_wmclass(GTK_WINDOW(customize_widget), "customize",
                            "Balsa");
     gtk_window_set_default_size(GTK_WINDOW(customize_widget), 600, 440);
 
-    child = create_toolbar_page(balsa_window_get_toolbar_model());
+    /* The order of pages must be consistent with the BalsaToolbarType
+     * enum. */
+    model = balsa_window_get_toolbar_model();
+    ui_manager = balsa_window_ui_manager_new(NULL);
+    child = create_toolbar_page(model, ui_manager);
+    g_object_unref(ui_manager);
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), child,
                              gtk_label_new(_("Main window")));
 
-    child = create_toolbar_page(sendmsg_window_get_toolbar_model());
+    model = sendmsg_window_get_toolbar_model();
+    ui_manager = sendmsg_window_ui_manager_new(NULL);
+    child = create_toolbar_page(model, ui_manager);
+    g_object_unref(ui_manager);
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), child,
                              gtk_label_new(_("Compose window")));
 
-    child = create_toolbar_page(message_window_get_toolbar_model());
+    model = message_window_get_toolbar_model();
+    ui_manager = message_window_ui_manager_new(NULL);
+    child = create_toolbar_page(model, ui_manager);
+    g_object_unref(ui_manager);
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), child,
                              gtk_label_new(_("Message window")));
 
     option_frame = gtk_frame_new(_("Toolbar options"));
     gtk_container_set_border_width(GTK_CONTAINER(option_frame), 6);
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(customize_widget)->vbox),
-                       option_frame, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(content_area), option_frame, FALSE, FALSE, 0);
 
     option_box = gtk_vbox_new(FALSE, 6);
     gtk_container_set_border_width(GTK_CONTAINER(option_box), 6);
@@ -169,6 +198,13 @@ customize_dialog_cb(GtkWidget * widget, gpointer data)
     gtk_box_pack_start(GTK_BOX(option_box), wrap_button, FALSE, FALSE, 0);
 
     gtk_widget_show_all(customize_widget);
+
+    /* Now that the pages are shown, we can switch to the page
+     * corresponding to the toolbar that the user clicked on. */
+    type =
+        GPOINTER_TO_INT(g_object_get_data
+                        (G_OBJECT(widget), BALSA_TOOLBAR_MODEL_TYPE));
+    gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), type);
 }
 
 /* get_toolbar_button_index:
@@ -243,16 +279,16 @@ get_toolbar_button_index(const char *id)
 static void
 wrap_toggled_cb(GtkWidget * widget, GtkNotebook * notebook)
 {
-    gint i, j;
+    gint i;
     GtkWidget *child;
     ToolbarPage *page;
     
-    balsa_app.toolbar_wrap_button_text = GTK_TOGGLE_BUTTON(widget)->active;
+    balsa_app.toolbar_wrap_button_text =
+        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 
-    j = gtk_notebook_get_current_page(notebook);
     for (i = 0; (child = gtk_notebook_get_nth_page(notebook, i)); i++) {
         page = g_object_get_data(G_OBJECT(child), BALSA_KEY_TOOLBAR_PAGE);
-        balsa_toolbar_refresh(page->toolbar);
+        balsa_toolbar_model_changed(page->model);
     }
 }
 
@@ -289,9 +325,18 @@ static void
 standard_button_cb(GtkWidget *widget, ToolbarPage * page)
 {
     balsa_toolbar_model_clear(page->model);
-    balsa_toolbar_refresh(page->toolbar);
+    gtk_widget_set_sensitive(page->standard_button, FALSE);
     tp_page_refresh_available(page);
     tp_page_refresh_current(page);
+    balsa_toolbar_model_changed(page->model);
+}
+
+static void
+style_button_cb(GtkWidget *widget, ToolbarPage * page)
+{
+    gboolean handled;
+
+    g_signal_emit_by_name(page->toolbar, "popup-menu", &handled);
 }
 
 /* Callback for the "row-activated" signal for the available list. */
@@ -353,11 +398,11 @@ tp_dialog_response_cb(GtkDialog * dialog, gint response, gpointer data)
     switch (response) {
     case GTK_RESPONSE_DELETE_EVENT:
     case GTK_RESPONSE_CLOSE:
-        update_all_toolbars();
         gtk_widget_destroy(GTK_WIDGET(dialog));
         break;
     case GTK_RESPONSE_HELP:
-        gnome_help_display("balsa", "toolbar-prefs", &err);
+        gtk_show_uri(NULL, "ghelp:balsa?toolbar-prefs",
+                     gtk_get_current_event_time(), &err);
         if (err) {
             balsa_information(LIBBALSA_INFORMATION_WARNING,
 		    _("Error displaying toolbar help: %s\n"),
@@ -375,7 +420,7 @@ tp_dialog_response_cb(GtkDialog * dialog, gint response, gpointer data)
 /* Create a page for the main notebook.
  */
 static GtkWidget*
-create_toolbar_page(BalsaToolbarModel * model)
+create_toolbar_page(BalsaToolbarModel * model, GtkUIManager * ui_manager)
 {
     GtkWidget *outer_box;
     GtkWidget *toolbar_frame, *toolbar_scroll;
@@ -383,12 +428,12 @@ create_toolbar_page(BalsaToolbarModel * model)
     GtkWidget *lower_ctlbox, *button_box, *move_button_box, *center_button_box;
     GtkWidget *list_frame, *list_scroll;
     GtkWidget *destination_frame, *destination_scroll;
+    GtkWidget *style_button;
     ToolbarPage *page;
     GtkTreeSelection *selection;
 
     page = g_new(ToolbarPage, 1);
     page->model = model;
-    page->needs_refresh = FALSE;
 
     /* The "window itself" */
     outer_box=gtk_vbox_new(FALSE, 0);
@@ -404,11 +449,16 @@ create_toolbar_page(BalsaToolbarModel * model)
     gtk_container_add(GTK_CONTAINER(toolbar_frame), toolbar_ctlbox);
     gtk_container_set_border_width(GTK_CONTAINER(toolbar_ctlbox), 5);
 
+    /* The ui-manager has actions but no ui, so we add an empty toolbar. */
+    gtk_ui_manager_add_ui_from_string(ui_manager,
+                                      "<ui>"
+                                      "  <toolbar name='Toolbar'/>"
+                                      "</ui>",
+                                      -1, NULL);
+
     /* The preview is an actual, fully functional toolbar */
-    page->toolbar = balsa_toolbar_new(model);
-    g_object_add_weak_pointer(G_OBJECT(page->toolbar),
-                              (gpointer) & page->toolbar);
-    gtk_toolbar_set_style(GTK_TOOLBAR(page->toolbar), GTK_TOOLBAR_BOTH);
+    page->toolbar = balsa_toolbar_new(model, ui_manager);
+    gtk_widget_set_sensitive(page->toolbar, FALSE);
 
     /* embedded in a scrolled_window */
     toolbar_scroll=gtk_scrolled_window_new(NULL, NULL);
@@ -422,12 +472,18 @@ create_toolbar_page(BalsaToolbarModel * model)
     gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(toolbar_scroll),
                                           page->toolbar);
 
+    /* Button box */
+    button_box = gtk_hbutton_box_new();
+    gtk_box_pack_start(GTK_BOX(toolbar_ctlbox), button_box, FALSE, FALSE, 0);
+
     /* Standard button */
     page->standard_button =
         gtk_button_new_with_mnemonic(_("_Restore toolbar to standard buttons"));
+    gtk_container_add(GTK_CONTAINER(button_box), page->standard_button);
 
-    gtk_box_pack_start(GTK_BOX(toolbar_ctlbox), page->standard_button,
-		       FALSE, FALSE, 0);
+    /* Style button */
+    style_button = gtk_button_new_with_mnemonic(_("Toolbar _style..."));
+    gtk_container_add(GTK_CONTAINER(button_box), style_button);
 
     /* Done with preview */
 	
@@ -524,11 +580,15 @@ create_toolbar_page(BalsaToolbarModel * model)
 
     g_signal_connect(G_OBJECT(page->standard_button), "clicked",
 		       G_CALLBACK(standard_button_cb), page);
+    g_signal_connect(G_OBJECT(style_button), "clicked",
+		       G_CALLBACK(style_button_cb), page);
 
     gtk_widget_set_sensitive(page->add_button, FALSE);
     gtk_widget_set_sensitive(page->remove_button, FALSE);
     gtk_widget_set_sensitive(page->back_button, FALSE);
     gtk_widget_set_sensitive(page->forward_button, FALSE);
+    gtk_widget_set_sensitive(page->standard_button,
+                             !balsa_toolbar_model_is_standard(model));
 
     tp_page_refresh_available(page);
     tp_page_refresh_current(page);
@@ -546,7 +606,7 @@ tp_page_refresh_available(ToolbarPage * page)
     GtkTreeModel *model;
     GtkTreeIter iter;
     GtkTreePath *path;
-    GSList *legal = balsa_toolbar_model_get_legal(page->model);
+    GHashTable *legal = balsa_toolbar_model_get_legal(page->model);
     GSList *current = balsa_toolbar_model_get_current(page->model);
     int item;
 
@@ -561,9 +621,8 @@ tp_page_refresh_available(ToolbarPage * page)
 
     for (item = 0; item < toolbar_button_count; item++) {
         if (item > 0
-            && (!g_slist_find_custom(legal,
-                                     toolbar_buttons[item].pixmap_id,
-                                     (GCompareFunc) strcmp)
+            && (!g_hash_table_lookup(legal,
+                                     toolbar_buttons[item].pixmap_id)
                 || g_slist_find_custom(current,
                                        toolbar_buttons[item].pixmap_id,
                                        (GCompareFunc) strcmp)))
@@ -645,7 +704,6 @@ tp_page_refresh_preview(ToolbarPage * page)
                                             toolbar_buttons[item].pixmap_id,
                                             -1);
     }
-    balsa_toolbar_refresh(page->toolbar);
 }
 
 /* Create a GtkTreeView for an icon list.
@@ -749,7 +807,9 @@ tp_page_swap_rows(ToolbarPage * page, gboolean forward)
                                  tmp_path, NULL, FALSE, 0, 0);
     gtk_tree_path_free(tmp_path);
 
+    gtk_widget_set_sensitive(page->standard_button, TRUE);
     tp_page_refresh_preview(page);
+    balsa_toolbar_model_changed(page->model);
 }
 
 /* Add an item to a GtkTreeView's GtkListStore.
@@ -760,7 +820,7 @@ tp_store_set(GtkListStore * store, GtkTreeIter * iter, gint item)
     GdkPixbuf *pixbuf;
     gchar *text;
 
-    text = g_strdup(_(toolbar_buttons[item].button_text));
+    text = g_strdup(balsa_toolbar_button_text(item));
     replace_nl_with_space(text);
     pixbuf = (item > 0
               ? gtk_widget_render_icon(customize_widget,
@@ -811,8 +871,10 @@ tp_page_add_selected(ToolbarPage * page)
                                  FALSE, 0, 0);
     gtk_tree_path_free(path);
 
+    gtk_widget_set_sensitive(page->standard_button, TRUE);
     tp_page_refresh_preview(page);
     tp_page_refresh_available(page);
+    balsa_toolbar_model_changed(page->model);
 }
 
 /* Remove an item from the page's current list.
@@ -840,8 +902,10 @@ tp_page_remove_selected(ToolbarPage * page)
     }
     gtk_tree_path_free(path);
 
+    gtk_widget_set_sensitive(page->standard_button, TRUE);
     tp_page_refresh_preview(page);
     tp_page_refresh_available(page);
+    balsa_toolbar_model_changed(page->model);
 }
 
 /* Unwrap text.
